<?php
// include common file
include_once './includes/config.inc.php';
// check a user is logged in
check_login();

// define form fields
$fields = array(
	'name'=>array(
		'rule'=>'/.+/',
		'message'=>'Please enter a Store Name',
		'value'=>'',
		'required'=>TRUE
	),
	'address'=>array(
		'rule'=>'/.+/',
		'message'=>'Please enter a Store Address',
		'value'=>'',
		'required'=>TRUE
	),
	'telephone'=>array(
		'rule'=>'/[0-9 +]/',
		'message'=>'Please enter a Store Telephone',
		'value'=>'',
		'required'=>FALSE
	),
	'email'=>array(
		'rule'=>"/^([a-z0-9\+_\-']+)(\.[a-z0-9\+_\-']+)*@([a-z0-9\-]+\.)+[a-z]{2,6}$/ix",
		'message'=>'Please enter a Store Email',
		'value'=>'',
		'required'=>FALSE
	),
	'website'=>array(
		'rule'=>'/.+/',
		'message'=>'Please enter a Store Website',
		'value'=>'',
		'required'=>FALSE
	),
	'description'=>array(
		'rule'=>'/.+/',
		'message'=>'Please enter a Store Description',
		'value'=>'',
		'required'=>FALSE
	),
	'latitude'=>array(
		'rule'=>'/[0-9.\-]/',
		'message'=>'Please enter a valid Store Latitude',
		'value'=>'',
		'required'=>TRUE
	),
	'longitude'=>array(
		'rule'=>'/[0-9.\-]/',
		'message'=>'Please enter a valid Store Longitude',
		'value'=>'',
		'required'=>TRUE
	)
);

// check for valid id
if(!isset($_GET['id']) || !is_numeric($_GET['id'])) {
	$_SESSION['flash'] = array('type'=>'bad','msg'=>'Invalid Id');
	redirect(ROOT_URL.'stores.php');
}

// get store from db
$db = db_connect();
$store = $db->get_row("SELECT stores.* FROM stores WHERE stores.id=".$db->escape($_GET['id']));
if(empty($store)) {
	$_SESSION['flash'] = array('type'=>'bad','msg'=>'Invalid Id');
	redirect(ROOT_URL.'stores.php');
}

// build upload directory
$upload_dir = ROOT.'imgs/stores/'.$store['id'].'/';
// resize image width
$resize_image_width = 100;

// delete image
if(isset($_POST['delete_image'])) {
	// get the image filename
	$delete = array_keys($_POST['delete_image']);
	$image = $delete[0];

	// check file exists
	if(file_exists($upload_dir.$image)) {
		// delete the image
		if(!@unlink($upload_dir.$image)) {
			$_SESSION['flash'] = array('type'=>'bad','msg'=>'There was a problem deleting the image: '.$v);
		} else {
			$_SESSION['flash'] = array('type'=>'good','msg'=>'The Image was successfully deleted');
		}
	} else {
		$_SESSION['flash'] = array('type'=>'bad','msg'=>'The Image you selected to delete doesn\'t exist, please try again');
	}
	
redirect(ROOT_URL.'stores_edit.php?id='.$store['id']);
}

// form submitted
if($_POST) {
	$errors = array();
	foreach($fields as $k=>$v) {
		// only validate fields that are supposed to exist
		if(isset($_POST[$k])) {
			// if field required / force validation if entered
			$required = (isset($v['required'])) ? (!empty($_POST[$k])) ? TRUE : $v['required']  : TRUE ;
			// check against regex
			if(isset($v['rule']) && $required && !preg_match($v['rule'], $_POST[$k]) ) {
				// check against regex
				if(isset($v['rule']) && !preg_match($v['rule'], $_POST[$k]) ) {
					// save message
					if(isset($v['message']) && !empty($v['message'])) {
						$errors[] = $v['message'];
					}
				}
			}
		
		// save value ready to be populated by form
		$fields[$k]['value'] = $_POST[$k];
		}
	}
	
	// deal with file upload
	if($_FILES && $_FILES['file']['error'] != 4) {
		// list of allowed mimetypes
		$allowed_mimetypes = array('image/jpeg');

		if(!is_dir($upload_dir)) {
			create_dir($upload_dir);
		}
		
		// check for valid upload filetype
		if(!in_array($_FILES['file']['type'],$allowed_mimetypes)) {
			$errors[] = 'Invalid file type, only Jpeg images are allowed';
		} else {
			// load image
			$img  = new Image(array('filename'=>$_FILES['file']['tmp_name']));
			// image has been succesfully loaded
			if($img !== FALSE) {
				// resize Image
				if($img->resize_to_width($resize_image_width)) {
					// make the filename safe
					$safe_name = strtolower(str_replace(' ','_',preg_replace('/[^a-zA-Z0-9\-_. ]/','',$_FILES['file']['name'])));
					
					// save Image
					if(!$img->save($upload_dir.$safe_name)) {
						$errors[] = 'There was a problem saving the resized Image, please try again';
					}
				} else {
					$errors[] = 'There was a problem resizing the Image, please try again';
				}
			} else {
				$errors[] = 'There was a problem initilizing the Image Class';
			}
		}
	}
	
	if(empty($errors)) {
		// automatically approve this store
		$_POST['approved'] = 1;
		
		if(!$db->update('stores',$_POST,$_GET['id'])) {
			$errors[] = 'There was a problem editing the Store, please try again';
		} else {
			$_SESSION['flash'] = array('type'=>'good','msg'=>'The Store was successfully edited');
			redirect(ROOT_URL.'stores.php');
		}
	}
} else {
	// pre-populate field values
	foreach($fields as $k=>$v) {
		if(isset($store[$k])) {
			$fields[$k]['value'] = $store[$k];
		}
	}
}

// get store images
$images = array();
if(is_dir($upload_dir)) {
	$images = get_files($upload_dir);
	foreach($images as $k=>$v) {
		$images[$k] = ROOT_URL.'imgs/stores/'.$store['id'].'/'.$v;
	}
}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html>
<head>
	<title>Edit a Store</title>
	<link rel="stylesheet" type="text/css" href="./css/style.css" media="all" />
	<script type="text/javascript" src="./js/jquery-1.3.2.min.js"></script>
	<script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=false"></script>
	<script type="text/javascript" src="./js/jquery-common.js"></script>
</head>
<body id="stores">
	<div id="wrapper">
		<div id="header">
			<h1>Store Locator</h1>
			<ul id="nav">
				<li class="n_dashboard"><a href="./">Dashboard</a></li>
				<li class="n_stores"><a href="./stores.php">Stores</a></li>
				<li class="n_logout"><a href="./logout.php">Logout</a></li>
			</ul>
		</div>
		<div id="main">
			<h2>Edit a Store</h2>
			<?php echo flash(); ?>
			<?php if(isset($errors) && !empty($errors)): ?>
			<ul class="flash_bad">
				<?php foreach($errors as $k=>$v): ?>
				<li><?php echo $v; ?></li>
				<?php endforeach; ?>
			</ul>
			<?php endif; ?>

			<p>The Map will automatically focus and display a marker if your address is found</p>
			<div id="map_canvas" style="width:100%; height:300px;"></div>
			<div id="ajax_msg"></div>

			<form method='post' action='./stores_edit.php?id=<?php echo $store['id']; ?>' id='form_add_store' enctype="multipart/form-data">
				<fieldset>
					<legend>Edit a Store</legend>
					<div class='input'>
						<label>Name: <span class='required'>*</span></label>
						<input type='text' name='name' id='name' value='<?php echo $fields['name']['value']; ?>' />
					</div>
					<div class='input'>
						<label>Address: <span class='required'>*</span></label>
						<input type='text' name='address' id='address' value='<?php echo $fields['address']['value']; ?>' />
						<span>The Latitude and Longitude will be automatically populated once an address is given and you move focus away from the form field</span>
					</div>
					<div class='input'>
						<label>Telephone:</label>
						<input type='text' name='telephone' id='telephone' value='<?php echo $fields['telephone']['value']; ?>' />
					</div>
					<div class='input'>
						<label>Email:</label>
						<input type='text' name='email' id='email' value='<?php echo $fields['email']['value']; ?>' />
					</div>
					<div class='input'>
						<label>Website:</label>
						<input type='text' name='website' id='website' value='<?php echo $fields['website']['value']; ?>' />
					</div>
					<div class='input'>
						<label>Description:</label>
						<textarea name='description' id='description' rows="5" cols="40"><?php echo htmlentities($fields['description']['value']); ?></textarea>
					</div>
					<div class='input'>
						<label>Image:</label>
						<input type="file" name="file" id="file" <?php if(!empty($images)) {echo 'disabled="disabled"';} ?>/>
						<span>The Image will be automatically resized to a thumbnail. Only JPG files are accepted</span>
					</div>
					
					<!-- LOOP THROUGH AND DISPLAY UPLOADED IMAGES -->
					<?php if(!empty($images)): ?>
					<div class="input">
						<?php foreach($images as $k=>$v): ?>
						<div class="image">
							<img src="<?php echo $v; ?>" alt="Image" />
							<button type="submit" name="delete_image[<?php echo basename($v); ?>]" id="delete_image" value="<?php echo basename($v); ?>">Delete</button>
						</div>
						<?php endforeach; ?>
					</div>
					<?php endif; ?>
					
					<div class="row two">
					<div class='input first'>
						<label>Latitude:</label>
						<input type='text' name='latitude' id='latitude' value='<?php echo $fields['latitude']['value']; ?>' />
					</div>
					<div class='input second'>
						<label>Longitude:</label>
						<input type='text' name='longitude' id='longitude' value='<?php echo $fields['longitude']['value']; ?>' />
					</div>
					</div>

					<div class='input buttons'>
						<button type='submit' name='save' id='save'>Save</button>
					</div>
				</fieldset>
			</form>

		</div>
	</div>
</body>
</html>