<?php
// include common file
include_once './includes/config.inc.php';
// new db instance
$db = new DB(array(
	'hostname'=>HOSTNAME,
	'username'=>DB_USERNAME,
	'password'=>DB_PASSWORD,
	'db_name'=>DB_NAME
));

// stop on db fail
if($db===FALSE) {
	$db_errors = $db->errors;
}

// distance form options
$distances = array(
	1=>'1 Mile',
	5=>'5 Miles',
	10=>'10 Miles',
	15=>'15 Miles',
	20=>'20 Miles',
	25=>'25 Miles',
	30=>'30 Miles',
);

// deal with ajax request
if(isset($_POST['ajax'])) {
	// get nearby stores
	if(isset($_POST['action']) && $_POST['action']=='get_nearby_stores') {
		// check lat/lng has been passed
		if(!isset($_POST['lat']) || !isset($_POST['lng'])) {
			// output json
			echo json_encode(array('success'=>0,'msg'=>'Latitude/Longitude not passed'));
		exit;
		}

		// sql for getting nearby stores
		$sql = "SELECT *, ( 3959 * ACOS( COS( RADIANS(".$_POST['lat'].") ) * COS( RADIANS( latitude ) ) * COS( RADIANS( longitude ) - RADIANS(".$_POST['lng'].") ) + SIN( RADIANS(".$_POST['lat'].") ) * SIN( RADIANS( latitude ) ) ) ) AS distance FROM stores WHERE status=1 AND approved=1 HAVING distance <= ".$_POST['distance']." ORDER BY distance";
		// get stores in JSON format
		echo get_json_stores($sql);
	}
exit;
}

// form errors
$errors = array();
// deal with normal form submission
// used when javascript is disabled
if($_POST) {
	if(isset($_POST['address']) && empty($_POST['address'])) {
		$errors[] = 'Please enter an address/Postcode';
	} else {
		// your google api key
		// get one here: http://code.google.com/apis/maps/signup.html
		$google_api_key = 'ABQIAAAAyeYxDXjOZeSl8P0ID3NRshT2yXp_ZAY8_ufC3CFXhHIE1NvwkxQNID4BIKXpGWFm65tzPUPH4VEerA';
		// current region
		// check the official documentation to change region
		// http://code.google.com/apis/maps/documentation/v3/services.html#CountryCodes
		// requires a ccTLD (county code top-level domain)
		// for a list of ccTLD's visit: http://en.wikipedia.org/wiki/CcTLD
		$region = 'uk';

		// geocode address
		$tmp = file_get_contents("http://maps.google.com/maps/geo?q=".urlencode($_POST['address'])."&gl={$region}&output=xml&sensor=false&key={$google_api_key}");
		$xml = XML2Array($tmp);
		// lookup successful
		if($xml['Response']['Status']['code']=='200') {
			// get latitude/longitude
			$coords = explode(',', $xml['Response']['Placemark']['Point']['coordinates']);
			// if valid
			if(isset($coords[0]) && isset($coords[1])) {
				// build data
				$data = array(
					'name'=>$v['name'],
					'address'=>$v['address'],
					'latitude'=>$coords[1],
					'longitude'=>$coords[0]
				);

				// sql for getting nearby stores
				$sql = "SELECT *, ( 3959 * ACOS( COS( RADIANS(".$coords[1].") ) * COS( RADIANS( latitude ) ) * COS( RADIANS( longitude ) - RADIANS(".$coords[0].") ) + SIN( RADIANS(".$coords[1].") ) * SIN( RADIANS( latitude ) ) ) ) AS distance FROM stores WHERE status=1 HAVING distance <= ".$db->escape($_POST['distance'])." ORDER BY distance";
				// get local stores
				$stores = $db->get_rows($sql);

				// no stores
				if(empty($stores)) {
					$errors[] = 'No Stores were found with address: '.$_POST['address'];
				}
			} else {
				$errors[] = 'An invalid response was returned, please try another address';
			}
		} else {
			$errors[] = 'Address Not Found: '.$_POST['address'];
		}
	}
}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html>
<head>
	<title>Store Locator</title>
	<link rel="stylesheet" type="text/css" href="<?php echo ROOT_URL; ?>css/style.css" media="all" />
	<script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=false"></script>
	<script type="text/javascript" src="<?php echo ROOT_URL; ?>js/jquery-1.3.2.min.js"></script>
	<script type="text/javascript" src="<?php echo ROOT_URL; ?>js/jquery-common.js"></script>
</head>
<body id="locator">
	<div id="wrapper">
		<div id="header">
			<h1>Store Locator</h1>
			<?php include ROOT."templates/nav.inc.php"; ?>
		</div>

		<div id="main">
			<h2>Find Your Nearest Store</h2>

			<?php echo flash(); ?>

			<noscript>
			<p class="flash_bad">
				Your browser currently doesn't support javascript or you have it turned off.
				Functionality will be limited and will only return a list of nearby stores.
			</p>
			</noscript>

			<?php if(isset($db_errors) && !empty($db_errors)): ?>
			<ul class="flash_bad">
				<li>You have the following database errors:</li>
				<?php foreach($db_errors as $k=>$v): ?>
				<li><?php echo $v; ?></li>
				<?php endforeach; ?>
			</ul>
			<?php endif; ?>

			<?php if(isset($errors) && !empty($errors)): ?>
			<ul class="flash_bad">
				<li>You have the following errors:</li>
				<?php foreach($errors as $k=>$v): ?>
				<li><?php echo $v; ?></li>
				<?php endforeach; ?>
			</ul>
			<?php endif; ?>

			<p>
				Insert your address/postcode to find your nearest store. Click on the Map Markers for additional information.
			</p>

			<?php if(isset($stores) && !empty($stores)): ?>
			<ul class="flash_good">
				<li>The following Stores were found:</li>
				<?php foreach($stores as $k=>$v): ?>
				<li><?php echo $v['name'].' - '.$v['address'].' ('.number_format($v['distance']).' miles)' ?></li>
				<?php endforeach; ?>
			</ul>
			<?php endif; ?>

			<div id="ajax_msg"></div>
			
			<form method="post" action="./index.php" id="store_locator">
				<fieldset>
					<legend>Store Locator</legend>
					<div class="input">
						<label>Address/Postcode: <span class="required">*</span></label>
						<input type="text" name="address" id="address" value="<?php if(isset($_POST['address'])){ echo $_POST['address'];} ?>" />
						<span>Try these search terms: "Manchester", "Bolton", "M20", "BL1"</span>
					</div>
					<div class="input">
						<label>Distance: <span class="required">*</span></label>
						<select name="distance" id="distance">
							<?php
							// populate selected option
							$selected = 1;
							if(isset($_POST['distance'])) {
								$selected = $_POST['distance'];
							}
							?>
							<?php foreach($distances as $k=>$v): ?>
							<option value="<?php echo $k; ?>" <?php if($selected == $k){ echo 'selected="selected"';} ?>><?php echo $v; ?></option>
							<?php endforeach; ?>
						</select>
					</div>
					<div class="input buttons">
						<button type="submit" name="find" id="find">Find</button>
					</div>
				</fieldset>
			</form>

			<div id="map_canvas" class="hide"></div>
		</div>
	</div>
<?php include ROOT."templates/footer.inc.php"; ?>
</body>
</html>