<?php
// includes
include_once './includes/config.inc.php';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html>
<head>
	<title>Store Locator - Usage</title>
	<link rel="stylesheet" type="text/css" href="<?php echo ROOT_URL; ?>css/style.css" media="all" />
</head>
<body id="usage">
	<div id="wrapper">
		<div id="header">
			<h1>Store Locator</h1>
			<?php include ROOT."templates/nav.inc.php"; ?>
		</div>

		<div id="main">
			<h2>Usage</h2>

			<h3>Setting up the Database</h3>
			<p>
				Below is the SQL that will create the database and the appropriate
				tables. A sample admin user is also created. All passwords are
				hashed using md5 encryption and a salt is used. You can change the
				password salt in the <strong>'/admin/includes/config.inc.php'</strong> file. To manually
				insert a new passwork look at the top of the <strong>'/admin/login.php'</strong> file
				and you will see some commented out code that can be used to display
				a hashed password. Note that if you do change the salt the admin user created below
				will not work.
			</p>

<pre><code>
/* create database */
CREATE DATABASE `store_locator`;

/* create stores table */
CREATE TABLE `stores` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL,
  `address` varchar(255) NOT NULL,
  `telephone` varchar(25) NOT NULL DEFAULT '',
  `email` varchar(255) NOT NULL DEFAULT '',
  `website` varchar(25) NOT NULL DEFAULT '',
  `description` text NOT NULL,
  `approved` tinyint(1) NOT NULL DEFAULT '0',
  `latitude` float NOT NULL DEFAULT '0',
  `longitude` float NOT NULL DEFAULT '0',
  `created` datetime NOT NULL,
  `modified` datetime NOT NULL,
  `status` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id`)
);

/* create users table */
CREATE TABLE `users` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `username` varchar(50) NOT NULL,
  `password` varchar(50) NOT NULL,
  `created` datetime NOT NULL,
  `modified` datetime NOT NULL,
  `status` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id`)
);

/* create an admin user */
insert  into `users`(`username`,`password`) values ('admin','4e654249ab4cfd74089bc883bbbec93a');
</code></pre>

			<h3>Setting up the Admin Panel</h3>
			<p>
				You must supply your database information and this is entered in the
				<strong>/admin/includes/config.inc.php</strong> file. You must also
				enter the directory of the admin folder and the address of the admin panel.
				These are used for redirection purposes and so that the correct paths are found.
				Some paths in the html or relative so that you shouldn't have to hard code these in.
			</p>

<pre><code>
// define database settings
define('HOSTNAME','localhost');
define('DB_USERNAME','database_username');
define('DB_PASSWORD','database_password');
define('DB_NAME','store_locator');
</code></pre>

			<p>
				Once you have supplied all the relevant data and that an admin user exists in the
				database you should be able to login and access the admin panel.
			</p>

			<h3>Admin Panel</h3>
			<p>
				To view to the admin panel visit the <strong>'/admin'</strong> section. If you
				are not logged in you will be redirected to the login panel. Input
				your username/password and you will be sent to the main stores page.
			</p>

			<div class="image">
			<img src="./imgs/screenshots/1-Login.png" alt="Login Screen" />
			</div>
			
			<h3>Stores</h3>
			<p>
				The main Stores page lists all currently active Stores that are in the database.
				To add a new store click the <strong>Add New Store</strong> link in the top
				right of the page. To edit or delete a specific Store use the links under
				the <strong>Action</strong> column.
			</p>

			<div class="image">
			<img src="./imgs/screenshots/2-Main-stores-page.png" alt="Main Stores Page" />
			</div>

			<h3>Adding Stores</h3>
			<p>
				To add a Store click the <strong>Add New Store</strong> link on the main Stores page.
				Here you can input a Store Name, Store Address, and the Longitude and Latitude values. Once
				an address has been inserted the page will attempt to find the address using Google. If found
				the Longitude and Latitude will be populated and the Map will update with the found address.
			</p>

			<div class="image">
			<img src="./imgs/screenshots/4-Add-store-2.png" alt="Adding a Store" />
			</div>

			<h3>Editing Stores</h3>
			<p>
				To edit a Store click the <strong>Edit</strong> link under the <strong>Actions</strong>
				column. The edit page will be displayed which is similar to the add page. Here
				you will be able to edit the Store details and change the address if incorrect.
			</p>

			<div class="image">
			<img src="./imgs/screenshots/5-Edit-store.png" alt="Editing a Store" />
			</div>

			<h3>Deleting Stores</h3>
			<p>
				To delete a Store click the <strong>Delete</strong> link under the <strong>Actions</strong>
				column. A confirmation box will be displayed, if you select yes the Store will be
				flagged as deleted in the database. To recover the deleted Store change the <strong>status</strong>
				field from <strong>0</strong> to <strong>1</strong>
			</p>

			<h3>Approving Stores</h3>
			<p>
				Stores that have added by users of the Store Locator are entered into the database
				with a status of 'Not Approved', this means that they must be approved by an admin
				user before they are visible via the search. To do this simply click the "Approve" link
				in the admin panel.
			</p>

			<h3>Importing Multiple Stores</h3>
			<p>
				An <strong>'/admin/import.php'</strong> file has been included that
				will allow you to easily import multiple stores all in one go by-passing
				the admin panel. You will first need an Google API key which can be
				found <a href="http://code.google.com/apis/maps/signup.html">here</a>, once you
				have your key you can insert it into the variable at the top of the script.
			</p>
			<p>
				To add multiple Stores simply populate the <strong>$stores</strong> array with
				the store name and the address and visit <strong>/admin/import.php</strong>. The
				script will loop through each of the stores, attempt to find the latitude/longitude
				and then insert the Store into the database. Any errors will be displayed on screen.
			</p>


			<h3>Setting up the Store Locator</h3>
			<p>
				Similarly to the Admin panel you must enter your database information in the
				<strong>'/includes/config.inc.php'</strong> file, along with the root path
				and the address of the store locator folder.
			</p>
			<p>
				Once you have supplied all the relevant data and Stores exist in the database
				the serach functionality will be fully working.
			</p>
			
		</div>
	</div>
<?php include ROOT."templates/footer.inc.php"; ?>
</body>
</html>