<?php
/* 
Plugin Name: Element Place
Plugin URI: http://codecanyon.net/user/designcise/portfolio
Description: "Element Place" allows positioning of HTML elements relative to other HTML elements in the document, or the window or document object. It can be useful for creating a variety of things such as ads, overlays, autocomplete, widgets, modal windows, lightboxes etc.
Version: 1.0
Author: Designcise
Author URI: http://codecanyon.net/user/designcise
*/

// Globals
global $wpdb, $element_place_table_name, $element_place_db_ver;
$element_place_table_name = $wpdb->prefix . "element_place";
$element_place_db_ver = "1.0";


/* * HELPER FUNCTIONS
 */
// Normalize data for front-end
function element_place_prepare($data) {
	// prepare data
	$data['selector'] = '$(\'' . $data['selector'] . '\')';
	
	if($data['relativeTo'] != 'window' && $data['relativeTo'] != 'document') {
		$data['relativeTo'] = '$(\'' . $data['relativeTo'] . '\')';
	}
	
	$data['position'] = '\'' . $data['position'] . '\'';
	$data['x'] = '\'' . $data['x'] . '\'';
	$data['y'] = '\'' . $data['y'] . '\'';
	
	if($data['z'] == 'auto') {
		$data['z'] = "'{$data['z']}'";
	}
	
	$data['inBoundX'] = ($data['inBoundX']) ? 'true' : 'false';
	$data['inBoundY'] = ($data['inBoundY']) ? 'true' : 'false';
	
	if($data['boundingBox'] != 'window' && $data['boundingBox'] != 'document') {
		$data['boundingBox'] = '$(\'' . $data['boundingBox'] . '\')';
	}
	
	$data['includeMargin'] = ($data['includeMargin']) ? 'true' : 'false';
	
	return $data;
}

// Normalize data for front-end
function element_place_normalize($data) {
	// prepare data	
	$data['includeOnPages'] = explode(",", $data['includeOnPages']);
	
	$data['inBoundX'] = ($data['inBoundX']) ? 'true' : 'false';
	$data['inBoundY'] = ($data['inBoundY']) ? 'true' : 'false';
	
	$data['includeMargin'] = ($data['includeMargin']) ? 'true' : 'false';
	
	$data['customCSS'] = empty($data['customCSS']) ? '' : $data['customCSS'];
	$data['customJS'] = empty($data['customJS']) ? '' : $data['customJS'];
	
	return $data;
}

// Create document-level script for front-end
function element_place_create($element_place_table_data) {
	// normalize for front-end
	$element_place_table_data = element_place_prepare($element_place_table_data);
	
	// prepare
	$str = 	"\r\n<script type=\"text/javascript\">";
	$str .=	"\r\njQuery(document).ready(function(\$) {	";
		$str .=	"\r\n\t{$element_place_table_data['selector']}.place({";
			$str .=	"\r\n\t\t'relativeTo': {$element_place_table_data['relativeTo']},";
			$str .=	"\r\n\t\t'position': {$element_place_table_data['position']},";
			$str .=	"\r\n\t\t'x': {$element_place_table_data['x']},";
			$str .=	"\r\n\t\t'y': {$element_place_table_data['y']},";
			$str .=	"\r\n\t\t'z': {$element_place_table_data['z']},";
			$str .=	"\r\n\t\t'offsetX': {$element_place_table_data['offsetX']},";
			$str .=	"\r\n\t\t'offsetY': {$element_place_table_data['offsetY']},";
			$str .=	"\r\n\t\t'inBoundX': {$element_place_table_data['inBoundX']},";
			$str .=	"\r\n\t\t'inBoundY': {$element_place_table_data['inBoundY']},";
			$str .=	"\r\n\t\t'boundingBox': {$element_place_table_data['boundingBox']},";
			$str .=	"\r\n\t\t'includeMargin': {$element_place_table_data['includeMargin']}";
		$str .=	"\r\n\t});";
	$str .=	"\r\n});";
	$str .=	"\r\n</script>";
	
	// return
	return $str;
}


/* * Plug-in Install and Uninstall
 */
register_activation_hook(__FILE__, 'element_place_install');
register_deactivation_hook( __FILE__, 'element_place_uninstall');

	// install
	function element_place_install() {		
		global $wpdb, $element_place_table_name, $element_place_db_ver;
		
		// create table
		if($wpdb->get_var("SHOW TABLES LIKE '$element_place_table_name'") != $element_place_table_name) {
			$sql = "CREATE TABLE $element_place_table_name (
				id INT(9) NOT NULL AUTO_INCREMENT,
				selector VARCHAR(250) NOT NULL,
				includeOnPages TEXT NOT NULL,
				relativeTo VARCHAR(250) NOT NULL,
				position ENUM('absolute', 'fixed') NOT NULL,
				x ENUM('left', 'leftEdge', 'center', 'right', 'rightEdge', 'overlay') NOT NULL,
				y ENUM('top', 'topEdge', 'center', 'bottom', 'bottomEdge', 'overlay') NOT NULL,
				z VARCHAR(6) DEFAULT 'auto' NOT NULL,
				offsetX VARCHAR(5) DEFAULT '0' NOT NULL,
				offsetY VARCHAR(5) DEFAULT '0' NOT NULL,
				inBoundX TINYINT(1) DEFAULT '1' NOT NULL,
				inBoundY TINYINT(1) DEFAULT '1' NOT NULL,
				boundingBox VARCHAR(250),
				includeMargin TINYINT(1) DEFAULT '0' NOT NULL,
				customCSS TEXT DEFAULT NULL,
				customJS TEXT DEFAULT NULL,
				PRIMARY KEY(id)
			);";
			
			// for updates
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			dbDelta($sql);
			
			// example: sticky nav
			$rows_affected = $wpdb->query(
				$wpdb->prepare("INSERT INTO $element_place_table_name VALUES(default, '#stickyNav', '0', 'window', 'fixed', 'overlay', 'bottomEdge', '1000', default, default, default, default, 'window', 0, default, default)")
			);
			// example: modal box
			$rows_affected = $wpdb->query(
				$wpdb->prepare("INSERT INTO $element_place_table_name VALUES(default, '#modalBox', '0', 'window', 'fixed', 'center', 'center', '1000', default, default, default, default, 'window', 0, default, default)")
			);
			
			add_option('element_place_db_ver', $element_place_db_ver);
		}
	}
	
	// uninstall
	function element_place_uninstall() {
		global $wpdb, $element_place_table_name, $element_place_db_ver;	
		$wpdb->query("DROP TABLE IF EXISTS $element_place_table_name");	
		
		delete_option('element_place_db_ver');
	}



/* * Register Scripts and Stylesheets to Use
 */
add_action('init', 'element_place_init');

	function element_place_init() {
		wp_register_script('jquery_alt', plugins_url('element_place/js/jquery-1.6.min.js'));
		
		wp_register_script('element-place-min-js', plugins_url('/js/jquery.place-min.js', __FILE__), array('jquery_alt'), '1.0');
		
		// avaiable in admin-area only
		if(is_admin()) {
			// style sheets
			wp_register_style('element-place-layout', plugins_url('/css/layout.css', __FILE__), null, '1.0', 'screen');
			wp_register_style('element-place-layout-ie', plugins_url('/css/layout.ie.css', __FILE__), null, '1.0', 'screen');
			
			// javascripts
			wp_register_script('element-place-admin-js', plugins_url('/js/jquery.place-admin.js', __FILE__), array('jquery_alt'), '1.0');
		}
	}



/* * AJAX Calls/Response
 */
add_action('wp_ajax_element_place_load', 'element_place_page_load');			// page load
add_action('wp_ajax_element_place_req', 'element_place_data_req');				// data request
add_action('wp_ajax_element_place_add', 'element_place_data_add');				// data add/update
add_action('wp_ajax_element_place_delete', 'element_place_data_delete');		// data delete

	// when page is loaded
	function element_place_page_load() {	
		$response = array('error' => FALSE, 'msg' => '', 'send' => NULL);
		
		global $wpdb, $element_place_table_name;
		$total_set = $wpdb->get_var("SELECT COUNT(*) FROM $element_place_table_name" );
		
		if(!empty($total_set)) {
			// display a list of set elements as a dropdown
			$result = $wpdb->get_results("SELECT id, selector FROM $element_place_table_name", ARRAY_A);
			
			foreach($result as $row) {
				$response['send'][] = $row;
			}
		}
		else {
			$response['error'] = TRUE;
			$response['msg'] = 'Currently there are no elements set to be placed on the current website.';
		}
		
		// send response
		echo json_encode($response);
		die();
	}
	
	// when element place data is requested
	function element_place_data_req() {
		$response = array('error' => FALSE, 'msg' => '', 'send' => NULL);
		
		global $wpdb, $element_place_table_name;
		
		// display a list of set elements as a dropdown
		$result = $wpdb->get_results("SELECT * FROM $element_place_table_name WHERE id = " . $_POST['id'], ARRAY_A);
		
		if(count($result) > 0) {
			foreach($result as $row) {
				$response = element_place_normalize($row);
			}
		}
		else {
			$response['error'] = TRUE;
			$response['msg'] = 'The requested data did not return any results from the database. It could be that it has been deleted since you last requested data from server.';
		}
			
		// send response
		echo json_encode($response);
		die();
	}
	
	// when add/update request is received
	function element_place_data_add() {
		$response = array('error' => FALSE, 'msg' => '', 'send' => NULL);
		
		global $wpdb, $element_place_table_name;
		
		$response['type'] = 'update';
		
		//$wpdb->show_errors();
		
		$id = $_POST['id'];
		$css = ((isset($_POST['css'])) ? "'{$_POST['css']}'" : "default");
		$js = ((isset($_POST['js'])) ? "'{$_POST['js']}'" : "default");;
		
		// if id was received, update
		if(isset($id) && $id !== '') {
			// check if the selector name was changed
			$result = $wpdb->get_results("SELECT selector FROM $element_place_table_name WHERE id=$id", ARRAY_A);
			
			$update = TRUE;
			
			if(count($result) > 0) {
				// check if the selector name was changed
				if($result[0]['selector'] != $_POST['selector']) {
					// if it was then check if new selector already exists on selected pages
					$total_set = $wpdb->get_var("SELECT COUNT(*) FROM $element_place_table_name WHERE selector='{$_POST['selector']}' AND includeOnPages='{$_POST['includeOnPages']}'" );
					
					// throw error
					if(!empty($total_set)) {
						$update = FALSE;
						$response['error'] = TRUE;
						$response['msg'] = 'Could not update because settings for the selector "' . $_POST['selector'] . '" already exists for the selected pages. Try another selector name, or page, or update the settings for the other selector.';
					}
				}	
			}
			
			if($update) {
				// update
				$wpdb->query("UPDATE $element_place_table_name SET 
					selector = '{$_POST['selector']}', 
					includeOnPages = '{$_POST['includeOnPages']}', 
					relativeTo = '{$_POST['relativeTo']}', 
					position = '{$_POST['position']}', 
					x = '{$_POST['x']}', 
					y = '{$_POST['y']}', 
					z = '{$_POST['z']}', 
					offsetX = '{$_POST['offsetX']}', 
					offsetY = '{$_POST['offsetY']}', 
					inBoundX = {$_POST['inBoundX']}, 
					inBoundY = {$_POST['inBoundY']}, 
					boundingBox = '{$_POST['boundingBox']}', 
					includeMargin = {$_POST['includeMargin']}, 
					customCSS = $css, 
					customJS = $js 
				WHERE ID = $id");
			}
		}
		// else, add
		else {
			$response['type'] = 'add';
			
			// check if a rule for same selector, same page exists before!
			$total_set = $wpdb->get_var("SELECT COUNT(*) FROM $element_place_table_name WHERE selector='{$_POST['selector']}' AND includeOnPages='{$_POST['includeOnPages']}'" );
			
			if(!empty($total_set)) {
				$response['error'] = TRUE;
				$response['msg'] = 'Could not add because settings for the selector "' . $_POST['selector'] . '" already exists for the selected pages. Edit the previous rules to make any changes and update them.';
			}
			else {
				// insert into database
				$rows_affected = $wpdb->query(
					$wpdb->prepare("INSERT INTO $element_place_table_name VALUES(default, '{$_POST['selector']}', '{$_POST['includeOnPages']}', '{$_POST['relativeTo']}', '{$_POST['position']}', '{$_POST['x']}', '{$_POST['y']}', '{$_POST['z']}', '{$_POST['offsetX']}', '{$_POST['offsetY']}', {$_POST['inBoundX']}, {$_POST['inBoundY']}, '{$_POST['boundingBox']}', {$_POST['includeMargin']}, $css, $js)")
				);
			}
		}
			
		// send response
		echo json_encode($response);
		die();
	}
	
	// when delete request is received
	function element_place_data_delete() {
		$response = array('error' => FALSE, 'msg' => '', 'send' => NULL);
		
		$id = $_POST['id'];
		
		// if id was received, update
		if(isset($id) && $id !== '') {
			global $wpdb, $element_place_table_name;
			$total_set = $wpdb->get_var("SELECT COUNT(*) FROM $element_place_table_name" );
			
			// if delete was successful
			if(!empty($total_set)) {
				// display a list of set elements as a dropdown
				$result = $wpdb->query("DELETE FROM $element_place_table_name WHERE id=" . $_POST['id']);
				
				$response['post'] = $_POST['id'];
			}
			else {
				$response['error'] = TRUE;
				$response['msg'] = 'The item you\'re trying to delete does not exist in the database!';
			}
		}
		else {
			$response['error'] = TRUE;
			$response['msg'] = 'ID of the element to delete wasn\'t received by the server.';
		}
			
		// send response
		echo json_encode($response);
		die();
	}


/* * Document-level Scripts to include on non-admin pages.
 */
add_action('wp_head', 'element_place_inc_custom_scripts', 100);

function element_place_inc_custom_scripts() {	
	global $wp_query;
	$thePostID = (is_home()) ? '0' : $wp_query->post->ID;
	
	if(!is_null($thePostID)) {
		global $wpdb, $element_place_table_name, $element_place_table_data;	
		$result = $wpdb->get_results("SELECT * FROM $element_place_table_name", ARRAY_A);
		
		if(count($result) > 0) {
			$scripts = array();
			
			foreach($result as $row) {	
				// look for current page's id in list of include pages
				$found = strpos($row['includeOnPages'], strval($thePostID));
				
				if($found !== FALSE) {
					$current_script = element_place_create($row);
					
					// if some scripts have been added earlier
					if(count($scripts) > 0) {
						// go through them all
						foreach($scripts as $script) {
							// see if it matches current script text
							if($script === $current_script) {
								continue 2;
							}
						}
					}
					
					// add to array
					$scripts[] = $current_script;
					// print inline scripts
					echo $current_script;
				}
			}
		}
	}
}

/* * External Style Sheets to include on non-admin pages.
 */
add_action('wp_print_styles', 'element_place_inc_styles', 100);

function element_place_inc_styles() {
	if(!is_admin()) {		
		global $wp_query;
		$thePostID = (is_home()) ? '0' : $wp_query->post->ID;
		
		if(!is_null($thePostID)) {
			global $wpdb, $element_place_table_name, $element_place_table_data;	
			$result = $wpdb->get_results("SELECT * FROM $element_place_table_name", ARRAY_A);
		
			// database as rows
			if(count($result) > 0) {
				$i = 0;
				$styles = array();
			
				foreach($result as $row) {
					// look for current page's id in list of include pages
					$found = strpos($row['includeOnPages'], strval($thePostID));
					
					if($found !== FALSE) {				
						if(!(empty($row['customCSS']))) {
							
							// if some styles have been added earlier
							if(count($styles) > 0) {
								// go through them all
								foreach($styles as $style_url) {
									// see if it matches current style url
									if($style_url === $row['customCSS']) {
										continue 2;
									}
								}
							}
							
							// add to array
							$styles[] = $row['customCSS'];
							// add to queue
							wp_enqueue_style("element-place-custom$i", $row['customCSS'], null, '1.0', 'screen');
						}
					}
					
					$i += 1;
				}
			}
		}
	}
}

/* * External Scripts to include on non-admin pages.
 */
add_action('wp_print_scripts', 'element_place_inc_scripts', 100);

function element_place_inc_scripts() {
	// front-end specific scripts
	if(!is_admin()) {
		// posts
		global $wp_query;
		$thePostID = (is_home()) ? '0' : $wp_query->post->ID;
		
		if(!is_null($thePostID)) {
			// query
			global $wpdb, $element_place_table_name, $element_place_table_data;	
			$result = $wpdb->get_results("SELECT * FROM $element_place_table_name", ARRAY_A);
			
			// database as rows
			if(count($result) > 0) {
				$i = 0;
				$scripts = array();
				
				foreach($result as $row) {
					// look for current page's id in list of include pages
					$found = strpos($row['includeOnPages'], strval($thePostID));
					
					// if page we're on matches one in "includeOnPages"
					if($found !== FALSE) {
						wp_enqueue_script('element-place-min-js');
						
						// include user-specified (attached) js
						if(!(empty($row['customJS']))) {
							
							// if some scripts have been added earlier
							if(count($scripts) > 0) {
								// go through them all
								foreach($scripts as $script_url) {
									// see if it matches current script url
									if($script_url === $row['customJS']) {
										continue 2;
									}
								}
							}
							
							// add to array
							$scripts[] = $row['customJS'];
							// add to queue
							wp_enqueue_script("element-place-custom$i-js", $row['customJS'], array('jquery_alt', 'element-place-min-js'), '1.0');//$custom_js[] = $row['customJS'];
						}
					}
					
					$i += 1;
				}
			}
		}
	}
}



/* * Admin Menu, Content, Scripts and Style Sheets
 */
add_action('admin_menu', 'element_place_menu');

function element_place_menu() {	
	// admin page content
	$page = add_options_page('Element Place Settings', 'Element Place', 'manage_options', __FILE__, 'element_place_admin_content');
	
	// admin page scripts and style sheets
	add_action('admin_print_scripts-' . $page, 'element_place_js');
	add_action('admin_print_styles-' . $page, 'element_place_css');
	
	// javascripts
	function element_place_js() {
		if(is_admin()) {
			wp_enqueue_script('media-upload');
			wp_enqueue_script('thickbox');
			
			wp_enqueue_script('element-place-min-js');
			wp_enqueue_script('element-place-admin-js');
		}
	}
	
	// style sheets
	function element_place_css() {
		global $wp_styles;
		
		wp_enqueue_style('thickbox');
		
		wp_enqueue_style('element-place-layout');
		$wp_styles->add_data('element-place-layout-ie', 'conditional', 'lte IE 8');
	}

// content
function element_place_admin_content() {
	// check user permissions
	if(!current_user_can('manage_options'))  {
		wp_die( __('You do not have sufficient permissions to access this page.') );
	}
	
	global $wpdb, $element_place_table_name;
	$total_set = $wpdb->get_var("SELECT COUNT(*) FROM $element_place_table_name" );
	
	// admin page content
echo <<<CONTENT

	<!-- LAYOUT -->
	<div id="layout" class="wrap">
	
		<!-- Element Place Settings -->
		<div id="header">
			<div id="icon-options-general" class="icon32" style="margin-top: 0; padding-top: 0;"></div><h2 style="margin-top: 0; padding-top: 0;">Element Place</h2>
			<p style="margin: 0; color: black;"><em>Modify the settings below to place an element somewhere in the selected pages.</em></p>
		</div>
		
		
		<ul id="widgetDropdown">
			<li>
				<div class="smallContainer">
					<input type="radio" id="dropdownWindow" name="dropdownOptions" value="window" checked="checked" />
				</div>
				<div class="mediumContainer">
					<label for="dropdownWindow">Window</label>
				</div>
			</li>
			<li>
				<div class="smallContainer">
					<input type="radio" id="dropdownDocument" name="dropdownOptions" value="document" />
				</div>
				<div class="mediumContainer">
					<label for="dropdownDocument">Document</label>
				</div>
			</li>
			<li>
				<div class="smallContainer">
					<input type="radio" id="dropdownCustom" name="dropdownOptions" value="custom" />
				</div>
				<div class="mediumContainer">
					<label for="dropdownCustom">Custom</label>
				</div>
		</ul>
		
		<div id="widgetMsgBox"><div id="widgetMsgBoxClose">X</div><p></p></div>
		<div id="widgetFlashBox"></div>
		
		<!-- SECTION 1 -->
		<div id="container" class="wrapper odd">
			
			<div id="toolbar" class="underline">
				<!-- NAVIGATION -->
				<ol id="nav">
					<li><a href="edit.php?post_type=page">Create Element</a></li>
					<li>Select and Place Element</li>
				</ol>
				<!-- END NAVIGATION -->
				
				<input type="reset" id="btnCancel" class="right" value="Start Over" />
			</div>
			
			<form id="contentArea">			
				<ol>
					<!-- SELECT ELEMENT -->
					<li>
						<h4 class="underline">Select an Element</h4>
						
						<ul>
							<li class="full">
								<label for="selector" title="The CSS (or jQuery) selector to select an element on the specified page."><span class="required">*</span> Element Selector: </label>
								<input type="text" id="selector" name="selector" class="full" maxlength="250" value="#positionedBox" />
							</li>
							<li class="full">
								<label for="includeOnPages" title="The page on which the specified element will be looked for and placed."><span class="required">*</span> Place on Page(s): </label>
								<select id="includeOnPages" name="includeOnPages" class="full" multiple="multiple" style="height: 75px;">
CONTENT;

$frontpage_id = get_option('page_on_front');
$postspage_id = get_option('page_for_posts');

if($postspage_id == 0) {
	$option = '<option value="'.$postspage_id.'" selected="selected">Posts Page' . (($frontpage_id == $postspage_id) ? ' (Front Page)' : '') . '</option>';
	echo $option;
}

$pages = get_pages(); 

foreach($pages as $page) {
	$option = '<option value="'.$page->ID.'"' . (($page->ID == $postspage_id) ? ' selected="selected"' : '') . '>';
	$option .= $page->post_title . (($page->ID == $frontpage_id) ? ' (Front Page)' : '') . (($page->ID == $postspage_id) ? ' (Posts Page)' : '');
	$option .= '</option>';
	echo $option;
}

echo <<<CONTENT
								</select>
							</li>
							<li class="full">
								<input type="checkbox" id="checkAttachStyle" val="" /> <label for="checkAttachStyle" title="Add some styling to the placed element by specifying an external CSS file.">Attach CSS: </label>
								<input type="text" id="attachStyle" name="css" value="" class="full" />
							</li>
							<li class="full">
								<input type="checkbox" id="checkAttachCode" val="" /> <label for="checkAttachCode" title="Add some behavior to the placed element by specifying an external JavaScript.">Attach JavaScript: </label>
								<input type="text" id="attachCode" name="js" value="" class="full" />
							</li>
						</ul>
					</li>
					<!-- END SELECT ELEMENT -->
					
					<!-- PLACE ELEMENT -->
					<li>
						<h4 class="underline">Place an Element</h4>
						
						<ul>
							<li class="threeQuarter">
								<label for="position" title="The CSS position property that should be applied to the selected HTML element.">Position: </label>
								<select id="position" name="position" class="full">
									<option value="absolute" selected="selected">Absolute (default)</option>
									<option value="fixed">Fixed</option>
								</select>
							</li>
							<li class="quarter">
								<label for="z" title="The CSS z-index value that should be applied to the selected HTML element.">Z-Index: </label>
								<input type="text" id="z" name="z" value="1000" maxlength="6" class="full" />
							</li>
							<li class="threeQuarter">
								<label for="relativeTo" title="The HTML element, window or document object, relative to which the selected HTML element will be positioned.">Relative to: </label>
								<input type="text" id="relativeTo" name="relativeTo" class="full" maxlength="250" value="#staticBox" autocomplete="off" />
							<li class="quarter">
								<br />
								<input type="checkbox" id="includeMargin" name="includeMargin" value="false" />
								<label for="includeMargin" title="If true, margins of the relative to element are added to the calculation.">Include Margin</label>
							</li>
							<li class="threeQuarter">
								<label for="x" title="The horizontal alignment of the selected HTML element relative to the specified HTML element, window or document object.">X: </label>
								<select id="x" name="x" class="full">
									<option value="left">Left (default)</option>
									<option value="leftEdge" selected="selected">Left Edge</option>
									<option value="right">Right</option>
									<option value="rightEdge">Right Edge</option>
									<option value="center">Center</option>
									<option value="overlay">Overlay</option>
								</select>
							</li>
							<li class="quarter">
								<label for="offsetX" title="The amount of spacing to add or take away from the set vertical position of the selected HTML element.">Offset X: </label>
								<input type="text" id="offsetX" name="offsetX" value="0" maxlength="5" class="full" />
							</li>
							<li class="threeQuarter">
								<label for="y" title="The vertical alignment of the selected HTML element relative to the specified HTML element, window or document object.">Y: </label>
								<select id="y" name="y" class="full">
									<option value="top">Top (default)</option>
									<option value="topEdge">Top Edge</option>
									<option value="bottom">Bottom</option>
									<option value="bottomEdge" selected="selected">Bottom Edge</option>
									<option value="center">Center</option>
									<option value="overlay">Overlay</option>
								</select>
							</li>
							<li class="quarter">
								<label for="offsetY" title="The amount of spacing to add or take away from the set vertical position of the selected HTML element.">Offset Y: </label>
								<input type="text" id="offsetY" name="offsetY" value="0" maxlength="5" class="full" />
							</li>
							<li class="threeQuarter">
								<label for="boundingBox" title="The HTML element, window or document object; boundaries of which are used to bound an element inside a region.">Bounding Box: </label>
								<input type="text" id="boundingBox" name="boundingBox" class="full" maxlength="250" value="window" autocomplete="off" />
							</li>
							<li class="quarter">
								<div style="margin-bottom: 5px;">
									<input type="checkbox" id="inBoundX" name="inBoundX" value="true" checked="checked" /> 
									<label for="inBoundX" style="display: inline;" title="If true, the selected HTML element is kept inside the left/right edge of the bounding box.">inBoundX</label>
								</div>
								<div>
									<input type="checkbox" id="inBoundY" name="inBoundY" value="true" checked="checked" />	
									<label for="inBoundY" style="display: inline; margin-bottom: 0" title="If true, the selected HTML element is kept inside the top/bottom edge of the bounding box.">inBoundY</label>
								</div>
							</li>
						</ul>
					</li>
					<!-- END PLACE ELEMENT -->
				</ol>
				
				<div class="submit">
					<input type="hidden" id="itemID" name="id" value="" />
					<input type="submit" id="btnSubmit" value="Place Element" class="button-secondary" />
				</div>
			</form>
			<div id="sidebar">
				<div class="panel">
					<h4 class="underline"><input type="checkbox" id="livePreview" value="preview" checked="checked" /> <label for="livePreview">Live Preview:</label></h4>
				
					<div id="staticBox">#staticBox</div>
					<div id="positionedBox">#positionedBox</div>
				</div>
				
				<div class="panel">
					<h4 class="underline">Saved Elements<span id="savedElementsCount"> (0)</span>:</h4>
					
					<div id="setItemsContainer">A list of your saved settings will be displayed here.</div>
					
				</div>
			</div>
			
		</div>
		<!-- END SECTION 1 -->
		
	</div>
	<!-- END LAYOUT -->
	
CONTENT;
}
}

?>