jQuery(document).ready(function($) {	

	/* * COMMON STUFF
	 */	 
		$('input[type="text"], textarea').focus(function(e) {
			// select text in textboxes
			this.select();
		});
		
		/* Observes/listens the document for changes; the first message in all found is shown.
		 * Priority is given to error messages, then warnings and then success messages.
		 */
		function monitorNotifications() {
			// highest priority
			var errorFields = $('#container').find('.error');
			// medium priority
			var warningFields = $('#container').find('.warning');
			// lowest priority
			var successFields = $('#container').find('.success');
			
			if(errorFields.length > 0) {				
				// get the first field and display message
				showMsgBox(errorFields.eq(0), 'error');
			}
			else if(warningFields.length > 0) {
				// get the first field and display message
				showMsgBox(warningFields.eq(0), 'warning');
			}
			else if(successFields.length > 0) {
				// get the first field and display message
				showMsgBox(successFields.eq(0), 'success');
			}
			else {
				hideMsgBox();
			}
		}
		// execute
		self.setInterval(monitorNotifications, 1000);
		
		
		/* Finds a name for the specified field.
		 * 
		 * @param	field		Field to search for.
		 */
		function fieldToName(field) {
			var label = $(field).parent().children('label[for]');
			var name = $(field).attr('name');
			var id = $(field).attr('id');
			var text = $(field).text();
			
			if(label.length > 0) {
				return label.eq(0).text().replace(/(\*|\:)/ig, '');
			}
			else if(null != id && typeof id !== 'undefined' && id !== '') {
				return id;
			}
			else if(null != text && typeof text !== 'undefined' && text !== '') {
				return text;
			}
			else if(null != name && typeof name !== 'undefined' && name !== '') {
				return name;
			}
			// if everything fails...
			else {
				return String(field);
			}
		}
		
		/* Adds a message of the specified type to the element.
		 * 
		 * @param	element		Element to add message to.
		 * @param	type		'error', 'warning', 'success'.
		 * @param	msg			Message to add.
		 */
		function addMsg(element, type, msg) {
			// create namespace (e.g. "elementPlaceErrorMsg")
			var dataNS = 'elementPlace' + type.charAt(0).toUpperCase() + type.slice(1) + 'Msg';
			
			var selected = $(element);
			
			// add class
			if(!selected.hasClass(type)) {
				selected.addClass(type);
			}
			
			// set data
			selected.data(dataNS, msg);
		}
		
		
		/* Removes a message of the specified type from the element.
		 * 
		 * @param	element		Element to remove message from.
		 * @param	type		'error', 'warning', 'success'.
		 */
		function removeMsg(element, type) {
			// create namespace (e.g. "elementPlaceErrorMsg")
			var dataNS = 'elementPlace' + type.charAt(0).toUpperCase() + type.slice(1) + 'Msg';
			
			var selected = $(element), msg = selected.data(dataNS);
			
			// if there's a class of 'type' associated to element
			if(selected.hasClass(type)) {
				// remove it
				selected.removeClass(type);
			}
			
			// if data has been set previously
			if(msg) {
				// remove it
				selected.removeData(dataNS);
			}
		}
		
		/* Flashes the foreground/background of the specified block-level container element.
		 *
		 * @param	element		Block-level container element.
		 * @param	type		'error', 'warning', 'success'.
		 * @param	callback	(optional) Callback function to call. 
		 * @param	isOverlay	(optional) Determines whether to overlay or underlay.
		 */
		function flashOut(element, type, callback, isOverlay) {
			isOverlay = (null == isOverlay) ? false : isOverlay;
			
			// remove all classes associated with the widget
			$('#widgetFlashBox').removeClass();
			
			// make content area elements of a higher z-index
			// to have an underlay flash effect
			$(element).find('* :not(#positionedBox)').css({
				position: 'relative',
				'z-index': ((isOverlay) ? 1000 : 1001)
			});
			
			// show message box flash of specified "type"
			$('#widgetFlashBox').addClass(type).place({
				relativeTo: $(element),
				x: 'overlay',
				y: 'overlay',
				z: ((isOverlay) ? 1001 : 1000)
			}).show().fadeOut(1500, function() {
				$(element).find('* :not(#positionedBox)').css('position', 'static');
				
				$('html, body').animate({scrollTop: 0}, 1000);
				
				if(typeof callback === 'function') {
					callback.call(element);
				}
			});
		}
		
		/* Hides the Message Box. 
		 */
		function hideMsgBox() {
			$('#widgetMsgBox').fadeOut(1000)
			
			$('#btnCancel').removeClass('overlay');
		}
		
		/* Shows the Message Box.
		 *
		 * @param	element		Block-level container element.
		 * @param	type		'error', 'warning', 'success'.
		 * @param	callback	(optional) Callback function to call. 
		 */
		function showMsgBox(field, type, callback) {
			var dataNS = 'elementPlace' + type.charAt(0).toUpperCase() + type.slice(1) + 'Msg';
			var msg = $(field).data(dataNS);
			
			// if message exists
			if(typeof msg === 'string') {
				// remove all previous classes
				$('#widgetMsgBox').removeClass();
				
				$('#widgetMsgBox > p').html(msg);
				
				// add class
				if(!$('#widgetMsgBox').hasClass(type)) {
					$('#widgetMsgBox').addClass(type);
				}
				
				// place and show
				$('#widgetMsgBox').place({
					relativeTo: $('#toolbar'),
					x: 'overlay',
					y: 'overlay',
					z: 100
				}).show();
				
				// add class to cancel button
				if(!$('#widgetMsgBox').hasClass('overlay')) {
					$('#btnCancel').addClass('overlay');
				}
			}
		}
		
		/* Validates user input fields.
		 * 
		 * @param	fields		Array of fields to validate.
		 * @param	type		(optional) 'multi', 'number'.
		 * @param	callback	(optional) Callback function to call.
		 */
		function validate(fields, type, callback) {
			$.each(fields, function(i, field) {
				var value = (null != type && type === 'multi') ? (($(field).val() || []).join(',')) : ($(field).val() || '');
				var property = $(field).attr('id');
				
				// check for empty
				if(value === '') {					
					addMsg(field, 'error', 'You cannot leave the "' + fieldToName(field) + '" field empty!');
				}
				else {
					removeMsg(field, 'error');
				}
				
				if(null != type) {
					// check for numeric types
					if(type === 'number') {
						intValue = parseInt(value);
			
						// validate
						if(isNaN(intValue) || null == intValue) {						
							addMsg(field, 'error', 'You\'ve entered a non-numeric value for the "' + fieldToName(field) + '" field!');
							
							// special numeric case 'z-index' (also accepts 'auto')
							if(property === 'z') {
								if(value === 'auto') {
									removeMsg(field, 'error');
								}
								else {
									addMsg(field, 'error', 'The accepted values for the z-index fields are numbers and the value "auto"');
								}
							}
						}
						else {
							removeMsg(field, 'error');
						}
					}
				}
				
				if(typeof callback === 'function') {
					callback.call(field, (($(field).hasClass('error')) ? false : true));
				}
			});
		}
		
		/* Validates file extensions.
		 * 
		 * @param	fields		Field containing file url to validate.
		 * @param	fileExt		The extension it should be in.
		 * @param	callback	(optional) Callback function to call.
		 */
		function validateField(field, fileExt, callback) {			
			var url = field.val();
			var ext = url.lastIndexOf(".");
			
			// remove error class before (re-)validating
			removeMsg(field, 'error');
			
			// invalid file
			if(ext == -1) {
				addMsg(field, 'error', 'You seem to have selected a wrong file type. You must select a file with the extension "' + fileExt + '".');
			}
			// check further...
			else {
				ext = url.substr(ext+1, url.length);
				
				if(ext !== fileExt) {
					addMsg(field, 'error', 'The file extension of the file that you\'ve selected is invalid! You must select a file with the extension "' + fileExt + '".');
				}
				else {
					removeMsg(field, 'error');
				}
			}
			
			if(typeof callback === 'function') {
				callback.call(field, (($(field).hasClass('error')) ? false : true));
			}
		}
		
		/* Updates all element place related input fields.
		 */
		function updateFields() {
			// relativeTo, position
			var relativeTo = $('#positionedBox').place('relativeTo');
			relativeTo = (relativeTo === window) ? 'window' : ((relativeTo === document) ? 'document' : ('#' + $(relativeTo).attr('id')));
			$('#relativeTo').val(relativeTo);
			
			$('#position option[value="' + $('#positionedBox').place('position') + '"]').prop('selected', true);
			
			
			// x, y, z
			$('#x option[value="' + $('#positionedBox').place('x') + '"]').prop('selected', true);
			$('#y option[value="' + $('#positionedBox').place('y') + '"]').prop('selected', true);
			
			$('#offsetX').val($('#positionedBox').place('offsetX'));
			$('#offsetY').val($('#positionedBox').place('offsetY'));
			
			$('#z').val($('#positionedBox').place('z'));
			
			
			// bounds
			var inBoundX = $('#positionedBox').place('inBoundX'), inBoundY = $('#positionedBox').place('inBoundY');
			
			if(!inBoundX) {
				$('#inBoundX').prop('checked', false);
			}
			else {
				$('#inBoundX').prop('checked', true);
			}
			
			if(!inBoundY) {
				$('#inBoundY').prop('checked', false);
			}
			else {
				$('#inBoundY').prop('checked', true);
			}
			
			// disable bounding box
			if(!inBoundX && !inBoundY) {
				$('#boundingBox').prop('disabled', true);
			}
			else {
				$('#boundingBox').prop('disabled', false);
				
				var boundingBox = $('#positionedBox').place('boundingBox');
				boundingBox = (boundingBox === window) ? 'window' : ((boundingBox === document) ? 'document' : ('#' + $(boundingBox).attr('id')));
				
				$('#boundingBox').val(boundingBox);
			}
			
			// includeMargin
			var includeMargin = $('#positionedBox').place('includeMargin');
			
			if(!includeMargin) {
				$('#includeMargin').prop('checked', false);
			}
			else {
				$('#includeMargin').prop('checked', true);
			}
			
			// validate fields
			validate([$('#selector'), $('#relativeTo'), $('#boundingBox')]);
			validate([$('#includeOnPages')], 'multi');
			validate([$('#z'), $('#offsetX'), $('#offsetY')], 'number');
		}

		/* Refreshes live preview; needed when element is shown after it was previously
		 * hidden via "display: none" because the computation of values is usually not correct
		 * when element is not displaying (and if changes were made during that time).
		 */
		function livePreviewRefresh() {
			// if data not set
			if(!$('#positionedBox').data('placeOptions')) {
				// init
				$('#positionedBox').place({
					relativeTo: $('#staticBox'),
					x: 'leftEdge',
					y: 'bottomEdge',
					z: 1000
				});
				
				// and update fields accordingly
				updateFields();
			}
			
			// reposition
			$('#positionedBox').place({
				relativeTo: $('#positionedBox').place('relativeTo'),
				position: $('#positionedBox').place('position'),
				x: $('#positionedBox').place('x'),
				y: $('#positionedBox').place('y'),
				z: $('#positionedBox').place('z'),
				offsetX: $('#positionedBox').place('offsetX'),
				offsetY: $('#positionedBox').place('offsetY'),
				inBoundX: $('#positionedBox').place('inBoundX'),
				inBoundY: $('#positionedBox').place('inBoundY'),
				boundingBox: $('#positionedBox').place('boundingBox'),
				includeMargin: $('#positionedBox').place('includeMargin')
			});
		}

		/* Toggles the live preview based on whether it is set to be shown or hidden.
		 */
		function livePreviewToggle() {
			// if checked yes,
			if($('#livePreview').is(':checked')) {
				$('#staticBox').show();
				$('#positionedBox').show();
			
				// because when hidden and new values are applied, the computedValues aren't accurate! 
				// so need to reapply settings explicitly!
				livePreviewRefresh();
			}
			else {
				$('#staticBox').hide();
				$('#positionedBox').hide();
			}
		}
		
		/* Show/hides the live preview.
		 */
		function showLivePreview(show) {
			// default
			show = (null == show) ? true : show;
			
			// check live preview
			$('#livePreview').prop('checked', show);
			
			// delegate
			livePreviewToggle();
		}
		
		/* Reset everything to default. 
		 */
		function resetAll() {
			// hide message box
			hideMsgBox();
			
			// hide attachment window if open
			tb_remove();
			
			// remove error class from all
			$('#contentArea *').removeClass('error, success, warning');
			
			// set back to original position
			$('#positionedBox').place({
				relativeTo: $('#staticBox'),
				position: 'absolute',
				x: 'leftEdge',
				y: 'bottomEdge',
				z: 1000,
				offsetX: 0,
				offsetY: 0,
				inBoundX: true,
				inBoundY: true,
				boundingBox: window,
				includeMargin: false
			});
			
			// reset selector value
			$('#selector').val('#positionedBox');
			
			// change positioned box label to default
			$('#positionedBox').text('#positionedBox');
			// change static box label to default
			$('#staticBox').text('#staticBox');
			
			// reset any selected options
			$('#includeOnPages option').prop('selected', false);
			
			// select default option
			$('#includeOnPages option:first-child').prop('selected', true);
			
			// reset attachments
			$('#attachStyle').val('');
			$('#attachCode').val('');
			
			$('#checkAttachStyle').prop('checked', false);
			$('#checkAttachCode').prop('checked', false);
			
			// reset any loaded set items
			$('#setItems > li').removeClass('active');	
			
			// change submit button caption
			$('#btnSubmit').val('Place Element');	
			$('#btnSubmit').prop('disabled', false);
			
			$('#btnCancel').prop('disabled', false);
			
			// reset id field
			$('#itemID').val('');
			
			// show warning about reset
			$('#contentArea').data('elementPlaceWarningMsg', 'The document has just resetted itself to default settings!').addClass('warning');
	
			// reset dropdown 
			widgetDropdownResetAll();
	
			// update fields
			updateFields();
	
			// refresh live preview
			livePreviewToggle();
	
			// show message
			setTimeout(function() {
				$('#contentArea').removeData('elementPlaceWarningMsg').removeClass('warning');
			}, 5000);
		}

	/* * LIVE PREVIEW
	 */
		// initialize
		livePreviewToggle();
	
	
		$('#livePreview').click(function(e) {
			livePreviewToggle();
		});
	
	


	/* * ATTACHMENT SELECTOR
	 */	 
	 	// init
		var targetElem = null, livePreviewChecked = $('#livePreview').is(':checked');
		
		// when attachment fields are clicked
		$('#attachStyle, #attachCode').click(function(e) {
			e.preventDefault();
			
			targetElem = $(this);
			
			// before hiding live preview save its' state
			livePreviewChecked = $('#livePreview').is(':checked');
			
			// hide live preview
			if(livePreviewChecked) {
				showLivePreview(false);
			}
			
			// show media select modal
			tb_show('fileSelect', 'media-upload.php?post_id=1&type=file&TB_iframe=true');
		});
		
		// when attachment checkboxes are clicked
		$('#checkAttachStyle, #checkAttachCode').click(function() {
			var field = ($(this).attr('id') === 'checkAttachStyle') ? $('#attachStyle') : $('#attachCode');
			
			if($(this).is(':checked')) {
				field.trigger('click');
			}
			else {
				field.val('');
				// remove error class because field is empty now...
				if(field.hasClass('error')) {
					field.removeClass('error');
				}
			}
		});
		
		var win = window.dialogArguments || opener || parent || top;
		
		// send selected image to input
		win.send_to_editor = function(html) {	
			// retrieve selected value	
			fileURL = $(html).attr('href');
			
			// set field value
			$(targetElem).val(fileURL);
			
			// remove media modal
			tb_remove();
		};
	
		// if user cancels modal window or selects a file
		win.onunload = function() {
			var isStyleField = (targetElem.attr('id') === 'attachStyle') ? true : false;
			var field = (isStyleField) ? $('#attachStyle') : $('#attachCode');
			var checkbox = (isStyleField) ? $('#checkAttachStyle') : $('#checkAttachCode');
			
			// if field is empty
			if(field.val() === '') {
				// uncheck
				checkbox.prop('checked', false);
			}
			// field is not empty
			else {
				// check
				checkbox.prop('checked', true);
				
				// validate
				validateField(field, ((isStyleField) ? 'css' : 'js'));
			}			
			
			// if live preview was showing before modal was shown
			if(livePreviewChecked) {
				// show live preview
				showLivePreview(true);
			}
		};
		




	/* * DROPDOWN WIDGET
	 */
	 
	 	/* Resets the dropdown widget.
		 */
		function widgetDropdownResetAll() {
			// reset all
			$('#widgetDropdown li').removeClass('active').find('input[type="radio"]').prop('checked', false);
		}
		
		/* Makes the selected dropdown option active.
		 */
		function widgetDropdownActive() {
			// activate selected
			$('#widgetDropdown li input[type="radio"]:checked').parents('li').addClass('active');
		}
	
		// initialize dropdown widget stuff
		widgetDropdownActive();		
		
		// when a dropdown widget option is clicked
		$('#widgetDropdown li').click(function(e) {			
			// remove previously active list item
			widgetDropdownResetAll();
			
			var radioBox = $(this).find('input[type="radio"]').eq(0);
			var field = $(this).parents('li').eq(0).children('#relativeTo, #boundingBox').eq(0);
			
			// make current list item active
			$(this).addClass('active');
			radioBox.prop('checked', true);
			
			// special case; if clicked on custom box
			if(radioBox.val() === 'custom') {
				// focus field
				field.trigger('focus');
			}
			else {
				// set value
				field.val(radioBox.val());
				// validate
				validate([field], null, function() {
					// update
					normalizeApply(this);
				});
			}
		});
	
		

	
	
	/* * FORM RELATED
	 */	 
	 	/* Normalizes value (for JavaScript) and applies value in field 
		 * to the "selected" element.
		 *
		 * @param	field		Field to get value from.
		 */
		function normalizeApply(field) {
			var value = $(field).val();
			var property = $(field).attr('id');
			
			// if no error found
			if(!$(field).hasClass('error')) {				
				// normalize values
				if(value === 'window') {
					value = window;
				}
				else if(value === 'document') {
					value = document;
				}
				// custom
				else {
					value = $('#staticBox');
				}
			
				// apply
				$('#positionedBox').place(property, value);	
			}
		}
	 
	 	// this is where the dropdown widget is shown
		$('#relativeTo, #boundingBox').parent('li').click(function(e) {
			var field = $(this).find('input[type="text"]').eq(0);
				
			// if field are not disabled...			
			if(!field.is(':disabled')) {		
				widgetDropdownResetAll();
				
				// once showing, match the value of the container
				if(field.val() === 'window') {
					$('#widgetDropdown input[type="radio"][value="window"]').prop('checked', true);
				}
				else if(field.val() === 'document') {
					$('#widgetDropdown input[type="radio"][value="document"]').prop('checked', true);
				}
				else {
					$('#widgetDropdown input[type="radio"][value="custom"]').prop('checked', true);
				}
				
				widgetDropdownActive();
				
				$('#widgetDropdown').appendTo($(this)).show().place({
					relativeTo: field,
					x: 'overlay',
					y: 'bottom',
					z: 10000,
					inBoundX: false,
					inBoundY: false
				});
			}
		});
		
		// this is where the dropdown widget is hidden
		$('#relativeTo, #boundingBox').parent('li').mouseleave(function(e) {
			e.stopPropagation();
			$('#widgetDropdown').hide();
		});
		
		// when typing in "relativeTo" or "boundingBox" fields
		$('#relativeTo, #boundingBox').keyup(function(e) {
			var value = $(this).val();
			var property = $(this).attr('id');
			
			if(property === 'relativeTo') {
				// static box label
				$('#staticBox').text((value === 'window' || value === 'document') ? '#staticBox' : value);
			}
			
			// validate
			validate([$(this)], null, function() {
				normalizeApply(this);
			});
		});
		
		// when typing in "relativeTo" or "boundingBox" fields
		$('#relativeTo, #boundingBox').keydown(function(e) {			
			// reset previous
			widgetDropdownResetAll();
			
			var checkboxValue = 'custom';
			
			if($(this).val() === 'window') {
				checkboxValue = 'window';
			}
			else if($(this).val() === 'document') {
				checkboxValue = 'document';
			}
			
			// select
			$('#widgetDropdown input[type="radio"][value="' + checkboxValue + '"]').prop('checked', true);
			
			// select custom box
			widgetDropdownActive();
			
			// hide dropdown if enter was pressed!								
			if(e.keyCode === 13) {
				e.preventDefault();
				$('#widgetDropdown').hide();
				
				// validate
				validate([$(this)], null, function() {
					normalizeApply(this);
				});
			}
		});
		
		// when "relativeTo" or "boundingBox" fields are blurred
		$('#relativeTo, #boundingBox').blur(function() {
			var property = $(this).attr('id');
			var value = $(this).val();
			
			// validate
			validate([$(this)], null, function() {
				normalizeApply(this);
			});
		});
		
	 
	 	// resets everything
		$('#btnCancel').click(function(e) {
			e.preventDefault();
			
			if(confirm('Are you sure you want to cancel? This would cancel/reset all pending changes.')) {
				resetAll();	
			}
		});
		
		// when typing in "selector" field
		$('#selector').keyup(function() {
			validate([$(this)]);
			
			// change positioned box label
			$('#positionedBox').text($(this).val());
		});
		
		// when selecting pages to include script on
		$('#includeOnPages').click(function() {
			validate([$(this)], 'multi');
		});
		
		$('#position, #x, #y').change(function(e) {
			var property = $(this).attr('id');
			var value = $(this).find('option:selected').val();
			
			// apply
			$('#positionedBox').place(property, value);
		});
		
		$('#offsetX, #offsetY, #z').keyup(function() {
			var property = $(this).attr('id');
			var value = parseInt($(this).val());
			
			// validate
			validate([$(this)], 'number');
			
			// apply
			if(!$(this).hasClass('error')) {
				$('#positionedBox').place(property, value);
			}
		});
		
		$('#inBoundX, #inBoundY, #includeMargin').click(function() {
			var property = $(this).attr('id');
			var value = $('#' + property + ':checkbox:checked').val() === 'true' ? true : false;
			
			// apply
			$('#positionedBox').place(property, value);
			
			// toggle boundingBox "disabled" attribute
			if(property === 'inBoundX' || property === 'inBoundY') {
				// checkboxes unchecked
				if(!$('#inBoundX').is(':checked') && !$('#inBoundY').is(':checked')) {
					// disable bounding box
					$('#boundingBox').prop('disabled', true);
				}
				else {
					// enable bounding box
					$('#boundingBox').prop('disabled', false);
				}
			}
		});
		
		
		// submit form
		$('#contentArea').submit(function(e) {
			e.preventDefault();
			
			var errorFields = $(this).find('.error');
			
			// if fields have input error...
			if(errorFields.length > 0) {
				// flassh background
				flashOut($(this), 'error');
			}
			else {
				// disable button
				$('#btnSubmit').prop('disabled', true);
				// change value
				$('#btnSubmit').val('Processing Request...');
				
				// prepare custom query string
				var data = 	'selector=' + $('#selector').val();
					data +=	'&includeOnPages=' + ($('#includeOnPages').val() || []).join(',');
					data +=	(($('#attachStyle').val() === '') ? '' : ('&css=' + $('#attachStyle').val()));
					data +=	(($('#attachCode').val() === '') ? '' : ('&js=' + $('#attachCode').val()));
					data += '&position=' + $('#position option:selected').eq(0).val();
					data += '&z=' + $('#z').val();
					data += '&relativeTo=' + $('#relativeTo').val();
					data += '&includeMargin=' + ($('#includeMargin').is(':checked') ? 1 : 0);
					data += '&x=' + $('#x option:selected').eq(0).val();
					data += '&offsetX=' + $('#offsetX').val();
					data += '&y=' + $('#y option:selected').eq(0).val();
					data += '&offsetY=' + $('#offsetY').val();
					data += '&boundingBox=' + $('#boundingBox').val();
					data += '&inBoundX=' + ($('#inBoundX').is(':checked') ? 1 : 0);
					data += '&inBoundY=' + ($('#inBoundY').is(':checked') ? 1 : 0);
					data +=	(($('#itemID').val() === '') ? '' : ('&id=' + $('#itemID').val()));
				
				$.post(ajaxurl, data + '&action=element_place_add', function(response) {	
					// if no error		
					if(response.error) {
						// add error message from server
						$('#contentArea').data('elementPlaceErrorMsg', response.msg).addClass('error');
						
						flashOut($('#contentArea'), 'error', function() {							
							// hide message after 10secs							
							setTimeout(function() {
								$('#contentArea').removeData('elementPlaceErrorMsg').removeClass('error');
								
								// reset submit button
								$('#btnSubmit').prop('disabled', false).val(((response.type === 'add') ? 'Place Element' : 'Update Settings for ' + $('#setItems > li.active').text()));
							}, 10000);
							
							// for flash background
							$(this).removeData('elementPlaceErrorMsg');
						});
					}
					else {
						$('#btnCancel').prop('disabled', true);
						
						// add message tense
						response.type += (response.type === 'add') ? 'ed' : 'd';
						
						// add success message
						$('#contentArea').data('elementPlaceSuccessMsg', 'The entry has been successfully ' + response.type + ' to the database!').addClass('success');
						
						flashOut($('#contentArea'), 'success', function() {							
							// update list of set items
							getSavedItems(function(count) {
								if(response.type === 'updated' && count > 0) {
									// get id of item, because list gets refreshed by "getSavedItems()"
									var id = $('#itemID').val();
									var item = $('#setItems > li[id$=' + id + ']');
									
									// reset submit button
									$('#btnSubmit').prop('disabled', false).val('Update Settings for ' + item.text());
									
									// set it as active
									item.addClass('active');
									
									$('#btnCancel').prop('disabled', false);
								}
							});
							
							// hide message after 5secs
							setTimeout(function() {
								$('#contentArea').removeData('elementPlaceSuccessMsg').removeClass('success');
								
								if(response.type === 'added') {
									// reset everything
									resetAll();
								}
							}, 5000);
							
							// for flash background
							$(this).removeData('elementPlaceSuccessMsg');
						});
					}
					
				}, "json");
			}
		});
	
	
	/* * SET ITEMS
	 */		
	 	/* Retrieves saved element settings from the database
		 *
		 * @param	callback		(optional) Callback function to call.
		 */
		function getSavedItems(callback) {
			$.post(ajaxurl, 'action=element_place_load', function(response) {
				var count = 0;
				
				// if no error		
				if(!response.error) {
					var list = 	'<ol id="setItems">'
						// populate list items
						for(var i in response.send) {
							list +=	'<li id="setItem' + response.send[i].id + '">' + response.send[i].selector  + '<span class="delete"></span></li>';
							count += 1;
						}
					list 	+= '</ol>';
					
					$('#savedElementsCount').html(' (' + count + ')');
					
					// show
					$('#setItemsContainer').html(list);
				}
				// if error
				else {
					// show error message
					$('#setItemsContainer').html('<p id="setItems">' + response.msg + '</p>');
					
					// reset count to 0
					$('#savedElementsCount').html(' (' + count + ')');
				}
				
				if(typeof callback === 'function') {
					callback.call($('#setItemsContainer'), count);
				}
			}, "json");
		}
	
		// when page loads
		getSavedItems();
		
		// when saved element settings is clicked
		$('#setItems > li').live('click', function(e) {
			e.preventDefault();
			
			// set active link
			$(this).parent().find('li').removeClass('active');
			$(this).addClass('active');
			
			// get id
			var id = $(this).attr('id');
			id = id.substr('setItem'.length, id.length);
			
			// get text
			var text = $(this).text();
			
			// change button caption
			$('#btnSubmit').val('Update Settings for ' + text);
			
			
			// show loader instead of delete button
			$(this).find('span.delete').removeClass('delete').addClass('load');
			
			// page load request
			var data = 'id=' + id + '&action=element_place_req';
			var target = $(this);
			
			// post id and get json object of all fields
			$.post(ajaxurl, data, function(response) {
				if(response.error) {
					// add error message from server
					target.data('elementPlaceErrorMsg', response.msg).addClass('error');
					
					// hide message after 5 seconds
					setTimeout(function() {
						// remove error
						target.removeData('elementPlaceErrorMsg').removeClass('error');
						
						// refresh saved items list
						getSavedItems();
					}, 10000);
				}
				else {
					// remove error class from all
					$('#contentArea *').removeClass('error');
					
					// show delete button instead of loader
					$(target).find('span.load').removeClass('load').addClass('delete');
					
					// set position
					$('#positionedBox').place({
						relativeTo: (response.relativeTo === 'window') ? window : ((response.relativeTo === 'document') ? document : $(String(response.relativeTo))),
						position: String(response.position),
						x: String(response.x),
						y: String(response.y),
						z: (response.z === 'auto') ? String(response.z) : parseInt(response.z),
						offsetX: parseInt(response.offsetX),
						offsetY: parseInt(response.offsetY),
						inBoundX: (response.inBoundX === 'true') ? true : false,
						inBoundY: (response.inBoundY === 'true') ? true : false,
						boundingBox: (response.boundingBox === 'window') ? window : ((response.boundingBox === 'document') ? document : $(String(response.boundingBox))),
						includeMargin: (response.includeMargin === 'true') ? true : false
					});
					
					// update fields
					$('#selector').val(response.selector);
					
					// change positioned box label
					$('#positionedBox').text($('#selector').val());
					// change static box label
					var staticBoxValue = $('#relativeTo').val();
					$('#staticBox').text((staticBoxValue === 'window' || staticBoxValue === 'document') ? '#staticBox' : staticBoxValue);
					
					// highlight pages to include script on list
					if(typeof response.includeOnPages === 'object') {
						// deselect all
						$('#includeOnPages option').prop('selected', false);
						
						// select only required ones
						$.each(response.includeOnPages, function(i, option) {
							$('#includeOnPages option[value="' + option + '"]').prop('selected', true);
						});
					}
					
					// update attachments
					$('#attachStyle').val(response.customCSS);
					$('#attachCode').val(response.customJS);
					
					// auto reset to reflect changes
					$('#checkAttachStyle').prop('checked', (($('#attachStyle').val() !== '') ? true : false));
					$('#checkAttachCode').prop('checked', (($('#attachCode').val() !== '') ? true : false));
					
					// add id to hidden field
					$('#itemID').val(id);
					
					// update options fields to match preset
					updateFields();
				}
			}, "json");
		});
		
		// when delete button is clicked; delete
		$('#setItems > li > span.delete').live('click', function(e) {
			e.stopPropagation();
			
			var parent = $(this).parent('li');
			
			var text = parent.text();
			
			parent.addClass('delete');
			
			if(confirm('Are you sure you want to delete the settings for ' + text + '?')) {						
				// get id
				var id = $(this).parent('li').attr('id');
				id = id.substr('setItem'.length, id.length);
				
				// page load request
				var data = 'id=' + id + '&action=element_place_delete';
				
				// post data
				$.post(ajaxurl, data, function(response) {					
					// if error...
					if(response.error) {
						// add error message from server
						parent.data('elementPlaceErrorMsg', response.msg).addClass('error');
						
						// hide message after 5 seconds
						setTimeout(function() {
							// remove error
							parent.removeData('elementPlaceErrorMsg').removeClass('error');
							
							// refresh saved items list
							getSavedItems();
						}, 10000);
					}
					// if deleted successfully!
					else {
						// if no error, remove!
						$('#setItem' + id).fadeOut('slow', function() {
							$(this).remove();
							
							// update list
							getSavedItems();
							
							// if deleted item was previously active then...
							if($('#itemID').val() === id) {								
								// change submit button caption
								$('#btnSubmit').val('Place Element');
								
								// reset id field
								$('#itemID').val('');
							}
						});
					}
				}, "json");
			}
			else {
				$(this).parent('li').removeClass('delete');
			}
		});
	
});