/*
 * @author			Designcise
 * @created			12-April-2011
 * @revised			N/A
 * @description		"Element Place" is a jQuery utility plug-in that allows positioning of 
 * 					HTML elements relative to other HTML elements in the document, or the 
 * 					window or document object. It can be useful for creating a variety of 
 * 					things such as ads, overlays, autocomplete, widgets, modal windows, 
 * 					lightboxes etc.
 * 
 * @license			This JavaScript file is a part of a commercial package, available for purchase 
 *					at http://codecanyon.net/user/designcise/portfolio. Any illegal copying, 
 *					distribution, packaging or re-production of this script for commercial or 
 *					personal use is strictly prohibited and will be considered theft.
 *
 * @copyright		The author is the first owner of copyright and reserves all rights to
 *					all written work contained in this file. Distribution, re-production
 *					or commercial use of the written work in this file, without the author's 
 * 					signed permission, prior consent or a valid license, is strictly prohibited.
 *					The author is protected by the "Copyright, Designs and Patents Act 1988" of 
 *					the United Kingdom. Any infringement of the copyright, in or outside of the
 *					United Kingdom, may result in a lawsuit.
 */


jQuery(document).ready(function($) {
	
	// default position
	$('#positionedBox').place({
		relativeTo: $('#staticBox'),
		x: 'leftEdge',
		y: 'bottomEdge',
		z: 1000
	});
	
	// prepare code for code generation area
	function generateCode() {
		var codeStart = "jQuery('#positionedBox').place({\n";
		
			// initialize
			var relativeTo = $('#relativeTo option:selected').val();
			relativeTo = ((/\b(?:window|document)\b/.test(relativeTo)) ? relativeTo : ("jQuery('" + relativeTo + "')"));
			
			var position = $('#position option:selected').val();
			
			var x = $('#x option:selected').val(), y = $('#y option:selected').val();
			var offsetX = $('#offsetX').val(), offsetY = $('#offsetY').val(), z = $('#z').val();
			
			var inBoundX = (($('#inBoundX:checkbox:checked').val() === 'true') ? true : false), inBoundY = (($('#inBoundY:checkbox:checked').val() === 'true') ? true : false);
			
			var boundingBox = $('#boundingBox option:selected').val();
			boundingBox = ((/\b(?:window|document)\b/.test(boundingBox)) ? boundingBox : ("jQuery('" + boundingBox + "')"));
			
			var includeMargin = (($('#includeMargin:checkbox:checked').val() === 'true') ? true : false);
			
			
			// relativeTo, position
			var code = ("\trelativeTo: " + relativeTo);
			code	+= ((position === 'absolute') ? '' : (", \n\tposition: '" + position + "'"));
			
			// x, y, z
			code	+= ((x === 'left') ? '' : (", \n\tx: '" + x + "'"));
			code	+= ((y === 'top') ? '' : (", \n\ty: '" + y + "'"));
			code	+= ((z === 'auto') ? '' : (", \n\tz: " + z));
			
			// offsets
			code	+= ((offsetX == '0') ? '' : (", \n\toffsetX: " + offsetX));
			code	+= ((offsetY == '0') ? '' : (", \n\toffsetY: " + offsetY));
			
			// bounds
			code	+= ((inBoundX) ? '' : (", \n\tinBoundX: " + inBoundX));
			code	+= ((inBoundY) ? '' : (", \n\tinBoundY: " + inBoundY));
			code	+= ((!inBoundX && !inBoundY || boundingBox === 'window') ? '' : (", \n\tboundingBox: " + boundingBox));
			
			// includeMargin
			code	+= ((includeMargin) ? (", \n\tincludeMargin: " + includeMargin) : '');
		
		var codeEnd = "\n});";
		
		
		// code
		code = codeStart + code + codeEnd;
		$('#code').val(code);
	}
	
	// at first run
	generateCode();	
	
	// update values of fields to match pre-sets
	function updateFields() {
		
		// relativeTo, position
		var relativeTo = $('#positionedBox').place('relativeTo');
		relativeTo = (relativeTo === window) ? 'window' : ((relativeTo === document) ? 'document' : ('#' + $(relativeTo).attr('id')));
		$('#relativeTo option[value="' + relativeTo + '"]').attr('selected', true);
		
		$('#position option[value="' + $('#positionedBox').place('position') + '"]').attr('selected', true);
		
		
		// x, y, z
		$('#x option[value="' + $('#positionedBox').place('x') + '"]').attr('selected', true);
		$('#y option[value="' + $('#positionedBox').place('y') + '"]').attr('selected', true);
		
		$('#offsetX').val($('#positionedBox').place('offsetX'));
		$('#offsetY').val($('#positionedBox').place('offsetY'));
		
		$('#z').val($('#positionedBox').place('z'));
		
		
		// bounds
		var inBoundX = $('#positionedBox').place('inBoundX'), inBoundY = $('#positionedBox').place('inBoundY');
		
		if(!inBoundX) {
			$('#inBoundX').removeAttr('checked');
		}
		else {
			$('#inBoundX').attr('checked', 'checked');
		}
		
		if(!inBoundY) {
			$('#inBoundY').removeAttr('checked');
		}
		else {
			$('#inBoundY').attr('checked', 'checked');
		}
		
		// disable bounding box
		if(!inBoundX && !inBoundY) {
			$('#boundingBox').attr('disabled', true);
		}
		else {
			$('#boundingBox').attr('disabled', false);
			
			var boundingBox = $('#positionedBox').place('boundingBox');
			boundingBox = (boundingBox === window) ? 'window' : ((boundingBox === document) ? 'document' : ('#' + $(boundingBox).attr('id')));
			
			$('#boundingBox option[value="' + boundingBox + '"]').attr('selected', true);
		}
		
		
		// includeMargin
		var includeMargin = $('#positionedBox').place('includeMargin');
		
		if(!includeMargin) {
			$('#includeMargin').removeAttr('checked');
		}
		else {
			$('#includeMargin').attr('checked', 'checked');
		}
	}
	
	// monitor value change in select fields
	$('#position, #x, #y, #relativeTo, #boundingBox').change(function(e) {
		var property = $(this).attr('id');
		var value = $(this).find('option:selected').val();
		
		if(/\b(?:relativeTo|boundingBox)\b/.test(property)) {
			// normalize values
			if(value === 'window') {
				value = window;
			}
			else if(value === 'document') {
				value = document;
			}
			else {
				value = $(value);
			}
		}
		
		// apply
		$('#positionedBox').place(property, value);
		
		// generate code
		generateCode();
	});
	
	// update value change in text fields
	$('#offsetX, #offsetY, #z').keyup(function() {
		var property = $(this).attr('id');
		var value = parseInt($(this).val());
		
		// validate
		if(isNaN(value) || null === value) {
			value = (property === 'z') ? 'auto' : 0;
		}
		
		// apply
		$('#positionedBox').place(property, value);
	});
	
	$('#offsetX, #offsetY, #z').blur(function() {
		var property = $(this).attr('id');
		var value = parseInt($(this).val());
		
		// validate
		if(isNaN(value) || null === value) {
			$(this).val(((property === 'z') ? 'auto' : 0));
		}
		
		// generate code
		generateCode();
	});
	
	$('#inBoundX, #inBoundY, #includeMargin').click(function() {
		var property = $(this).attr('id');
		var value = $('#' + property + ':checkbox:checked').val() === 'true' ? true : false;
		
		// apply
		$('#positionedBox').place(property, value);
		
		// toggle boundingBox "disabled" attribute
		if(property === 'inBoundX' || property === 'inBoundY') {
			// checkboxes unchecked
			if(null == jQuery('#inBoundX:checkbox:checked').val() && null == jQuery('#inBoundY:checkbox:checked').val()) {
				$('#boundingBox').attr('disabled', true);
			}
			else {
				$('#boundingBox').attr('disabled', false);
			}
		}
		
		// generate code
		generateCode();
	});
	
	// auto-select text fields
	$('input[type="text"], textarea').click(function() {
		// select text
		this.select();
	});
	
	
	// Pre-set: Dropdown
	$('#presets a[href="#dropdown"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			relativeTo: $('#staticBox'),
			x: 'overlay',
			y: 'bottom',
			offsetY: -1
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Tooltip
	$('#presets a[href="#tooltip"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			relativeTo: $('#staticBox'),
			x: 'center',
			y: 'top'
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Info Tip
	$('#presets a[href="#infotip"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			relativeTo: $('#staticBox'),
			x: 'left',
			y: 'center',
			offsetX: 15
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Corner Ribbon
	$('#presets a[href="#cornerRibbon"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			relativeTo: $('#staticBox'),
			x: 'rightEdge',
			y: 'topEdge'
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Block Overlay
	$('#presets a[href="#blockOverlay"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			relativeTo: $('#staticBox'),
			x: 'overlay',
			y: 'overlay'
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Sticky Nav
	$('#presets a[href="#stickyNav"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			position: 'fixed',
			x: 'overlay',
			y: 'bottomEdge'
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Info Bar
	$('#presets a[href="#infoBar"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			position: 'fixed',
			x: 'overlay',
			y: 'topEdge'
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Modal
	$('#presets a[href="#modal"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			position: 'fixed',
			x: 'center',
			y: 'center'
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Sidebar
	$('#presets a[href="#sidebar"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			relativeTo: document,
			x: 'leftEdge',
			y: 'overlay',
			boundingBox: document
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
	// Pre-set: Dock
	$('#presets a[href="#dock"]').click(function(e) {
		e.preventDefault();
		
		// reset old options
		$('#positionedBox').place('reset')
		// set options
		.place({
			position: 'fixed',
			x: 'leftEdge',
			y: 'overlay'
		});
		
		// update options fields to match preset
		updateFields();
		
		// generate code
		generateCode();
	});
	
});