/*
 * jQuery plugin for 3d images rotate version 1.0
 * Alban Xhaferllari
 * albanx@gmail.com
 * Copyright http://www.albanx.com
 * 
 */
(function ($) {
    var methods = {
        init: function (options) {
            return this.each(function () {
                var settings = {
                    images: new Array(),
                    imagesPath: "",
                    prefix: "",
                    startFrame: 1,
                    sprite: "",
                    frames: 10,
                    sensivity: 0,
                    autoRotation: 1,
                    direction: 1,
                    speed: 70
                };
                var SRC = (settings.sprite == "") ? this.src : settings.sprite;
                eval("var	inlineOpts = {" + $(this).attr("inlineOpts") + "}");
                var $this = $(this);
                if (options) {
                    $.extend(settings, options)
                }
                if (inlineOpts) {
                    $.extend(settings, inlineOpts)
                }
                if (this.tagName != "IMG") {
                    $.error("Zoomer plugin applies only to img tag.");
                    return false
                }
                var EXT = "." + SRC.split(".").pop();
                var test_ext = EXT.toLowerCase();
                if (test_ext != ".jpg" && test_ext != ".jpeg" && test_ext != ".gif" && test_ext != ".png" && test_ext != ".bmp") {
                    EXT = ""
                }
                var MAIN_WIDTH = $this.width();
                var MAIN_HEIGHT = $this.height();
                var MAIN_TOP = false,
                    MAIN_LEFT = false;
                var CURR_W = 0,
                    CURR_H = 0;
                var REAL_W = 0,
                    REAL_H = 0;
                var windowDiv = $('<div class="ax-window" />').css({
                    cursor: "e-resize",
                    overflow: "hidden",
                    position: "relative",
                    left: 0,
                    top: 0
                }).appendTo($this.parent());
                $this.data("window", windowDiv);
                $this.data("settings", settings);
                var imgDiv = $('<div class="ax-images" />').css({
                    overflow: "hidden",
                    position: "absolute",
                    left: 0,
                    top: 0
                }).appendTo(windowDiv);
                var images = new Array();
                var imagesXY = new Array();
                var totalFrames = settings.frames;
                var notSprite = 1;
                if (settings.images.length > 0) {
                    images = settings.images;
                    settings.frames = new Object();
                    settings.frames[0] = images.length;
                    settings.frames[1] = 1;
                    notSprite = 1;
                    totalFrames = settings.images.length
                } else {
                    if (settings.prefix != "") {
                        if (settings.imagesPath == "") {
                            settings.imagesPath = SRC.substring(0, SRC.lastIndexOf("/")) + "/"
                        }
                        for (var i = 0; i < totalFrames; i++) {
                            images[i] = settings.imagesPath + settings.prefix + (i + settings.startFrame) + EXT
                        }
                        settings.frames = new Object();
                        settings.frames[0] = totalFrames;
                        settings.frames[1] = 1;
                        notSprite = 1
                    } else {
                        if (settings.sprite != "") {
                            totalFrames = settings.frames[0] * settings.frames[1];
                            images[0] = settings.sprite;
                            notSprite = 0
                        } else {
                            $.error("3dzoomer : No image option given.");
                            return false
                        }
                    }
                }
                var TOTAL_W = 0,
                    TOTAL_H = 0;
                var imgLoad = new Image();
                var loadedImages = 0;
                var loadedPercent = 0;
                imgLoad.onload = function () {
                    MAIN_WIDTH = ($this.height() > 30) ? $this.width() : this.width;
                    MAIN_HEIGHT = ($this.height() > 30) ? $this.height() : this.height;
                    TOTAL_W = MAIN_WIDTH * settings.frames[0];
                    TOTAL_H = MAIN_HEIGHT * settings.frames[1];
                    if (settings.sensivity == 0) {
                        settings.sensivity = MAIN_WIDTH / totalFrames
                    }
                    windowDiv.css({
                        width: MAIN_WIDTH,
                        height: MAIN_HEIGHT
                    });
                    imgDiv.css({
                        width: TOTAL_W,
                        height: TOTAL_H
                    });
                    var count = 0;
                    for (var r = 0; r < settings.frames[1]; r++) {
                        for (var c = 0; c < settings.frames[0]; c++) {
                            var coors = new Object();
                            coors.x = c * MAIN_WIDTH;
                            coors.y = r * MAIN_HEIGHT;
                            imagesXY[count] = coors;
                            count++
                        }
                    }
                    $this.hide();
                    if (notSprite == 1) {
                        setup(MAIN_WIDTH, MAIN_HEIGHT)
                    } else {
                        setup(TOTAL_W, TOTAL_H)
                    }
                };
                imgLoad.src = (notSprite == 1) ? images[0] : settings.sprite;

                function setup(realW, realH) {
                    var loadingDiv = $("<div />").appendTo(windowDiv).css({
                        "background-color": "white",
                        "z-index": 99,
                        opacity: 0.6,
                        width: "100%",
                        height: "100%",
                        position: "absolute",
                        left: 0,
                        top: 0
                    });
                    var loadingSpan = $("<span />").appendTo(loadingDiv).css({
                        "font-size": "16px",
                        border: "1px solid red",
                        "text-align": "center",
                        height: "22px",
                        width: "100%",
                        position: "absolute",
                        left: 0,
                        top: "45%"
                    });
                    var loadingBar = $("<span />").appendTo(loadingSpan).css({
                        position: "absolute",
                        opacity: 0.5,
                        width: 0,
                        height: "100%",
                        "background-color": "red",
                        top: 0,
                        left: 0
                    });
                    for (var j = 0; j < images.length; j++) {
                        $("<img />").css({
                            width: realW,
                            height: realH,
                            position: "absolute",
                            left: imagesXY[j].x,
                            top: imagesXY[j].y
                        }).appendTo(imgDiv).bind("load", function () {
                            loadedImages++;
                            loadedPercent = (loadedImages / totalFrames) * 100;
                            loadingBar.html("Loading " + loadedImages + "/" + totalFrames).css("width", (loadedPercent >> 0) + "%");
                            if (totalFrames == loadedImages || notSprite == 0) {
                                loadingDiv.remove()
                            }
                            if (notSprite == 0) {
                                loadedImages = totalFrames
                            }
                        }).attr("src", images[j])
                    }
                }
                var START_X = 0;
                var START_Y = 0;
                var MOUSEX = 0;
                var MOUSEY = 0;
                var MOUSE_PRESS = false;
                var touchy = ("ontouchstart" in document.documentElement) ? true : false;
                var move = "touchmove.axevent mousemove.axevent";
                var end = "touchend.axevent mouseup.axevent";
                var down = "touchstart.axevent mousedown.axevent";
                imgDiv.bind(down, function (e) {
                    e.preventDefault();
                    MOUSE_PRESS = true;
                    START_X = (typeof (e.originalEvent.touches) != "undefined") ? e.originalEvent.touches[0].pageX : e.pageX;
                    START_Y = (typeof (e.originalEvent.touches) != "undefined") ? e.originalEvent.touches[0].pageY : e.pageY;
                    clearInterval(imgDiv.rotateInterval)
                }).bind(move, function (e) {
                    e.preventDefault();
                    if (MOUSE_PRESS) {
                        MOUSEX = (typeof (e.originalEvent.touches) != "undefined") ? e.originalEvent.touches[0].pageX : e.pageX;
                        MOUSEY = (typeof (e.originalEvent.touches) != "undefined") ? e.originalEvent.touches[0].pageY : e.pageY;
                        imgDiv.rotate(MOUSEX - START_X)
                    }
                }).bind(end, function (e) {
                    MOUSE_PRESS = false
                }).mousewheel(function (e, delta) {
                    e.preventDefault();
                    var direct = (delta < 1) ? -1 : 1;
                    imgDiv.rotate(direct * (settings.sensivity + 1))
                });
                $(document).bind(end, function (e) {
                    MOUSE_PRESS = false
                });
                var CURR_IMG = 0;
                imgDiv.rotate = function (diff) {
                    if (Math.abs(diff) >= settings.sensivity) {
                        var sign = (diff > 0) ? 1 : -1;
                        sign = sign * settings.direction;
                        START_X = MOUSEX;
                        CURR_IMG = (CURR_IMG + sign + totalFrames) % totalFrames;
                        imgDiv.css({
                            left: -imagesXY[CURR_IMG].x,
                            top: -imagesXY[CURR_IMG].y
                        })
                    }
                };
                imgDiv.rotateTime = settings.autoRotation;
                if (imgDiv.rotateTime) {
                    imgDiv.rotateInterval = setInterval(function () {
                        if (totalFrames == loadedImages) {
                            imgDiv.rotate(settings.sensivity + 1);
                            if (CURR_IMG == 0) {
                                imgDiv.rotateTime--
                            }
                            if (imgDiv.rotateTime == 0) {
                                clearInterval(imgDiv.rotateInterval)
                            }
                        }
                    }, settings.speed)
                }
            })
        },
        destroy: function () {
            return this.each(function () {
                var $this = $(this);
                var x = $this.data("window");
                $this.removeData("window");
                x.remove();
                $this.show()
            })
        },
        option: function (option, value) {
            if (value != null && value != undefined) {
                return this.each(function () {
                    var $this = $(this);
                    var curr_setts = $this.data("settings");
                    curr_setts[option] = value;
                    $this.data("settings", curr_setts)
                })
            } else {
                var $this = $(this);
                var curr_setts = $this.data("settings");
                return curr_setts[option]
            }
        }
    };
    $.fn.viewer3d = function (method, options) {
        if (methods[method]) {
            return methods[method].apply(this, Array.prototype.slice.call(arguments, 1))
        } else {
            if (typeof method === "object" || !method) {
                return methods.init.apply(this, arguments)
            } else {
                $.error("Method " + method + " does not exist on jQuery.rotate3d")
            }
        }
    }
})(jQuery);