<?php

require_once 'application/Root/Root.php';

class Account_Controller extends Root_Controller {

	public function indexGet() {
		$this->_verifyUserAuth();

		try {
			$user = vista_get_user();

			$contactList = $user->getContactList();
			$activity_user_id_list = array($user->getId());
			foreach ( $contactList as $contact ) {
				$activity_user_id_list[] = $contact->getFromUserId();
			}

			$result_activity = PV::getDb()->select()
				->from('user_activity')
				->inWhere('user_id', $activity_user_id_list)
				->orderBy('date_create', 'DESC')
				->limit(30)
				->query();
			$activityList = new Artisan_Db_Iterator($result_activity, PV::getModel('user/activity'));
			$this->activityList = $activityList;

			$view = $this->_getUserTypeView('index');
			$this->renderLayout($view);
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$this->_showDisabledError();
		} catch ( Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$this->_showDisabledError();
		}

		return true;
	}


	/**
	 * ##############################
	 * ENABLING/DISABLING
	 * ##############################
	 */

	public function enablePost() {
		$this->setLayout(NULL);

		try {
			vista_get_user()->setStatus(USER_STATUS_ENABLED)->write();
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		$this->_getMessage()->pushSuccess(_('Welcome back! We are glad you decided to come back and can continue to help you.'));
		$this->_redirect($this->url('account/index'));

		return true;
	}

	public function disableGet() {
		$this->_verifyUserAuth();
		try {
			$this->renderLayout('disable');
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		return true;
	}

	public function disablePost() {
		$this->_verifyUserAuth();
		$this->setLayout(NULL);

		try {
			$user = vista_get_user();
			$user->setStatus(USER_STATUS_DISABLED)->write();
			$this->_getUserSession()->destroyLogin();
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		$this->_getMessage()->pushSuccess(_('You have successfully disabled your account. We hope we can help you out in the future!'));
		$this->_redirect($this->url('index/index'));

		return true;
	}

	public function disabledGet() {
		parent::renderLayout('disabled');
		return true;
	}


	/**
	 * ##############################
	 * LOGGING IN/LOGGING OUT
	 * ##############################
	 */

	public function loginPost() {

		try {
			$login = (array)$this->getParam('login');

			$email_address = er('email_address', $login);
			$password = er('password', $login);

			$db = PV::getDb();

			$vistaUserAuth = new Artisan_Auth_Db($db, 'user', 'email_address', 'password', 'password_salt', 'user_id');
			$user_id = $vistaUserAuth->authenticate($email_address, $password, 'vista_user_authentication_login_hook');

			$user = User_Factory::build($user_id);

			if (!$user->hasContentDirectory()) {
				$user->createContentDirectory();
			}

			$user->setDateLastlogin(time())->write();

			$this->_getUserSession()->setLogin($user_id);

			PV::getLog()->add(LOG_SUCCESS, "Successful login from user id: #{$user_id}");

			$redirect = 'account/index';
			if ( true === $this->_getSession()->exists('redirect') ) {
				$redirect = $this->_getSession()->from('redirect');
				$this->_getSession()->remove('redirect');
			}

			$this->_redirect($this->url($redirect));
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError(_('Sorry, your login credentials could not be found. Please try again.'));
			$this->_redirect($this->url('index/index'));
		}

		return true;
	}

	public function logoutGet() {
		$this->setLayout(NULL);

		try {
			$this->_getUserSession()->destroyLogin();
			$this->_getMessage()->pushSuccess(_('You have successfully logged out.'));
			$this->_redirect($this->url('index/index'));
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		return true;
	}


	/**
	 * ##############################
	 * OFFICE/BUSINESS STATUS
	 * ##############################
	 */

	public function setOfficeStatusPost($status, $echo=true) {
		$this->_verifyUserAuth(true);
		$this->setLayout(NULL);

		try {
			$status = intval($status);
			if ( false === in_array($status, array(USER_OFFICE_STATUS_IN_OFFICE, USER_OFFICE_STATUS_OUT_OFFICE, USER_OFFICE_STATUS_OFF)) ) {
				$status = USER_OFFICE_STATUS_OFF;
			}

			$user = vista_get_user();
			$user->setOfficeStatus($status)->write();
			$status_text = _('Availability Updated');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->addException($e);
			$status_text = $e->getMessage();
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$status_text = _('An error occurred when setting your availability.');
		}

		if ( true === $echo ) {
			echo $status_text;
		}

		return true;
	}

	public function setBusinessStatusPost($echo=true) {
		$this->_verifyUserAuth(true);
		$this->setLayout(NULL);

		try {
			$business_status = $this->getParam('business_status');
			if ( true === empty($business_status) ) {
				throw new Vista_Controller_Exception(_('The business status is empty.'));
			}

			$user = vista_get_user();
			PV::getModel('user/status')->setUserId($user->getId())
				->setValue($business_status)
				->write();
			PV::recordActivity(USER_ACTIVITY_UPDATE_STATUS, $user->getId(), 0, $business_status);

			$status_text = _('Status Updated');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->addException($e);
			$status_text = $e->getMessage();
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$status_text = _('An error occurred when updating your status.');
		}

		if ( true === $echo ) {
			echo $status_text;
		}

		return true;
	}


	/**
	 * ##############################
	 * UPDATING ACCOUNT
	 * ##############################
	 */

	public function photoGet() {
		$this->_verifyUserAuth();

		try {
			$this->user = vista_get_user();
			$this->renderLayout('photo');
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		return true;
	}

	public function photoPost() {
		$this->_verifyUserAuth();
		$user = vista_get_user();

		try {
			$profile_picture = (array)$this->getFilesParam('profile_picture');

			if ( false === empty($profile_picture['name']) ) {
				$uploader = $this->_savePhoto($profile_picture);

				$filename = $uploader->getFilename();
				$filename_med = $uploader->getFilenameMed();
				$filename_tn = $uploader->getFilenameTn();
				$user->setProfilePicture($filename)
					->setProfilePictureMed($filename_med)
					->setProfilePictureTn($filename_tn)
					->setComplete(USER_PROFILE_COMPLETE);

				$user->write();
			}

			PV::recordActivity(USER_ACTIVITY_UPLOAD_PHOTO, $user->getId());

			$this->_getMessage()->pushSuccess(_('Your photo was uploaded successfully!'));
			$this->_redirect($this->url('account/index'));
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError($e->getMessage());
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError(_('There was an error when uploading your photo. Please try again.'));
		}

		$this->user = $user;
		$this->renderLayout('photo');
	}

	public function updateGet() {
		$this->_verifyUserAuth();

		try {
			$this->user = vista_get_user()->get();
			$this->renderLayout($this->_getUserTypeView('profile'));
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		return true;
	}

	public function updatePost() {
		$this->_verifyUserAuth();

		try {
			$user = vista_get_user();
			$view = $this->_getUserTypeView('profile');

			$user_data = (array)$this->getParam('user');

			$profile_picture = (array)$this->getFilesParam('profile_picture');

			$validator = $this->buildValidator();
			$validator->load($view)->setData($user_data)->validate();

			if ( false === empty($profile_picture['name']) ) {
				$uploader = $this->_savePhoto($profile_picture);

				$filename = $uploader->getFilename();
				$filename_med = $uploader->getFilenameMed();
				$filename_tn = $uploader->getFilenameTn();
				$user->setProfilePicture($filename)
					->setProfilePictureMed($filename_med)
					->setProfilePictureTn($filename_tn);
			}

			if ($user->getUsername() != $user_data['username']) {
				$username_exists = vista_username_exists($user_data['username']);
				if ($username_exists) {
					throw new Vista_Controller_Exception(_('The username you chose is already in use. Please use a different one.'));
				}
			}

			$user->setUsername($user_data['username'])
				->setFirstname($user_data['firstname'])
				->setLastname($user_data['lastname'])
				->setTimeOffset($user_data['time_offset'])
				->setCompany($user_data['company'])
				->setUrl($user_data['url'])
				->setTwitter($user_data['twitter'])
				->setFacebook($user_data['facebook'])
				->setLinkedin($user_data['linkedin'])
				->setPosterous($user_data['posterous'])
				->setTumblr($user_data['tumblr'])
				->setComments($user_data['comments'])
				->setComplete(USER_PROFILE_COMPLETE);

			$user->write();
			PV::recordActivity(USER_ACTIVITY_UPDATE_PROFILE, $user->getId());

			$this->_getMessage()->pushSuccess(_('Your profile was updated successfully!'));
			$this->_redirect($this->url('account/update'));
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError($e->getMessage());
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError(_('There was an error when updating your profile. Please review it and try again.'));
		}

		$this->view->setValidator($validator);
		$this->user = $user_data;
		$this->renderLayout($view);

		return true;
	}


	/**
	 * ##############################
	 * REGISTRATION
	 * ##############################
	 */

	public function registerGet() {
		if ( true === $this->_getUserSession()->isLoggedIn() ) {
			$this->_getMessage()->pushError(_('Sorry, you are currently logged in and can not create a new account.'));
			$this->_redirect($this->url('index/index'));
		}

		$this->register = array();
		$this->register_form = $this->render('register-form');

		parent::renderLayout('register');

		return true;
	}

	public function registerPost() {
		if ( true === $this->_getUserSession()->isLoggedIn() ) {
			$this->_getMessage()->pushError(_('Sorry, you are currently logged in and can not create a new account.'));
			$this->_redirect($this->url('index/index'));
		}

		try {
			$register = (array)$this->getParam('register');
			$email_address = er('email_address', $register);
			$username = er('username', $register);

			$validator = $this->buildValidator();
			$validator->load('register')->setData($register)->validate();

			$email_address_exists = vista_user_email_exists($email_address);
			if ( true === $email_address_exists ) {
				throw new Vista_Controller_Exception(_('Sorry, the email address you are attempting to register with is already in use.'));
			}

			$username_exists = vista_username_exists($username);
			if ( true === $username_exists ) {
				throw new Vista_Controller_Exception(_('The username you chose is already in use. Please use a different one.'));
			}

			$password = er('password', $register);
			$password_repeat = er('password_repeat', $register);

			if ( $password != $password_repeat ) {
				throw new Vista_Controller_Exception(_('The two passwords you entered do not match.'));
			}

			$password_salt = asfw_create_salt();
			$password_hashed = asfw_compute_hash($password, $password_salt);

			$user = $this->_getNewUser(USER_TYPE_BUSINESS);
			$user_id = $user->setType(USER_TYPE_BUSINESS)
				->setGender($register['gender'])
				->setEmailAddress($register['email_address'])
				->setPassword($password_hashed)
				->setPasswordSalt($password_salt)
				->setUsername($username)
				->setFirstname($register['firstname'])
				->setLastname($register['lastname'])
				->setStatus(USER_STATUS_ENABLED)
				->setUpgrade(1)
				->write();

			/* Log the customer in at this point as well. */
			$this->_getUserSession()->setLogin($user_id);

			$user->sendWelcomeEmail();

			PV::getLog()->add(LOG_SUCCESS, "Created user account with email address '{$email_address}'.");

			$this->_getMessage()->pushSuccess(_('Thank you for creating an account!'));
			$this->_redirect($this->url('account/index'));
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError($e->getMessage());
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError(_('An error occurred when registering.'));
		}

		$this->view->setValidator($validator);
		$this->register = $register;
		$this->register_form = $this->render('account/register-form');

		/**
		 * This specifically uses the parents renderLayout method because
		 * we don't want the failed profile form rendered in the context
		 * of the profile layout.
		 */
		parent::renderLayout('register');

		return true;
	}


	/**
	 * ##############################
	 * RENDERING
	 * ##############################
	 */

	public function renderLayout($view) {
		$user = vista_get_user();

		$this->upgraded = $user->isUpgraded();
		$this->office_status = $user->getOfficeStatus();
		$this->content = $this->render($view);
		$this->user = $user;

		if ( true === $user->isBusiness() ) {
			$this->all_comment_count = $user->getCommentList()->length();
			$this->all_contact_count = $user->getContactList()->length();

			$this->pending_comment_count = $user->getCommentList()
				->filter('status = ?', USER_COMMENT_NEW)
				->fetch()
				->length();

			$this->pending_contact_count = $user->getContactList()
				->filter('status = ?', USER_CONTACT_NEW)
				->fetch()
				->length();

			$this->percent_complete = $user->getPercentComplete();
		} else {
			$this->all_favorite_count = $user->getFavoriteList()->length();
		}

		$layout = $this->_getUserTypeView('layout');
		parent::renderLayout('account/' . $layout);

		return true;
	}



	private function _savePhoto($photo_data) {
		$user = vista_get_user();

		$uploader = PV::getModel('uploader', $photo_data);
		$uploader->setAllowOverwrite(true)
			->setDestinationDirectory($user->getContentDirectory())
			->upload();

		$dest_dir = $uploader->getDestinationDirectory();

		$dest_file = $dest_dir . $uploader->getFilename();
		$dest_file_med = $dest_dir . $uploader->getFilenameMed();
		$dest_file_tn = $dest_dir . $uploader->getFilenameTn();

		$image = PV::getModel('image', $dest_file);
		$image->resize(500, 300)->writeJpg();

		$image = PV::getModel('image', $dest_file);
		$image->resize(220, 220)->writeJpg($dest_file_med);

		$image = PV::getModel('image', $dest_file);
		$image->resize(48, 48)->writeJpg($dest_file_tn);

		return $uploader;
	}

}