<?php

require_once 'application/Account/Account.php';

class Comment_Controller extends Account_Controller {

	public function indexGet($filter=NULL) {
		$this->_verifyUserAuth();

		try {
			$user = vista_get_user();

			if ( true === $user->isConsumer() ) {
				throw new Vista_Controller_Exception(_('Only business members can manage their comments.'));
			}

			$list = $user->getCommentList();
			if ( FILTER_PENDING == $filter ) {
				$list->filter('status = ?', USER_COMMENT_NEW);
			}

			$this->list = $list;
			$this->renderLayout('list');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$this->_showDisabledError($e->getMessage(), 'account/index');
		} catch ( Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$this->_showDisabledError();
		}

		return true;
	}




	public function addPost($profile_id, $status=USER_COMMENT_NEW, $echo=true) {
		$this->_verifyUserAuth(true);
		$this->setLayout(NULL);

		try {
			$comment = $this->getParam('comment');

			$user = vista_get_user();
			$profile = PV::getModel('user/profile', $profile_id);

			if ( true === empty($comment) ) {
				throw new Vista_Controller_Exception(_('The comment was empty and could not be created.'));
			}

			if ( false === $profile->isBusiness() ) {
				throw new Vista_Controller_Exception(_('Only business accounts can receive comments.'));
			}

			if ( false === $profile->enabled() ) {
				throw new Vista_Controller_Exception(_('The account you are attempting to add a comment to is disabled.'));
			}

			PV::getModel('user/comment')->setFromUserId($user->getId())
				->setToUserId($profile->getId())
				->setComment($comment)
				->setStatus($status)
				->write();

			$status_text = _('Comment successfully added.');

			if ( $user->getId() != $profile->getId() ) {
				$status_text = _('Comment successfully added for approval.');
				PV::getEmail()->send('account-pending-comment', $profile->getEmailAddress(), array(
					'firstname' => $profile->getFirstname()
					)
				);
			} else {
				PV::recordActivity(USER_ACTIVITY_POST_COMMENT, $user->getId(), $profile->getId(), $comment);
			}
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = $e->getMessage();
		} catch ( Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = _('An error occurred when adding a comment.');
		}

		if ( true === $echo ) {
			echo $status_text;
		}

		return true;
	}





	public function approvePost($comment_id, $echo=true) {
		$this->_verifyUserAuth(true);
		$this->setLayout(NULL);

		try {
			$this->_setStatus($comment_id, USER_COMMENT_APPROVED);
			$status_text = _('The comment was successfully approved.');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = $e->getMessage();
		} catch ( Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = _('An error occurred when approving the comment.');
		}

		if ( true === $echo ) {
			echo $status_text;
		}

		return true;
	}




	public function declinePost($comment_id, $echo=true) {
		$this->_verifyUserAuth(true);
		$this->setLayout(NULL);

		try {
			$this->_setStatus($comment_id, USER_COMMENT_DECLINED);
			$status_text = _('The comment was successfully declined.');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = $e->getMessage();
		} catch ( Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = _('An error occurred when declining the comment.');
		}

		if ( true === $echo ) {
			echo $status_text;
		}

		return true;
	}

	public function deletePost($comment_id, $echo=true) {
		$this->_verifyUserAuth(true);
		$this->setLayout(NULL);

		try {
			$user = vista_get_user();
			$comment = PV::getModel('user/comment', $comment_id);

			if ( false === $user->isBusiness() ) {
				throw new Vista_Controller_Exception(_('Only business accounts can delete comments.'));
			}

			if ( false === $comment->exists() ) {
				throw new Vista_Controller_Exception(_('That comment does not exist.'));
			}

			if ( false === $comment->belongsTo($user->getId()) ) {
				throw new Vista_Controller_Exception(_('You do not have permission to delete this comment.'));
			}

			$comment->delete();
			$status_text = _('The comment was successfully deleted.');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = $e->getMessage();
		} catch ( Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$status_text = _('An error occurred when deleting the comment.');
		}

		if ( true === $echo ) {
			echo $status_text;
		}

		return true;
	}


	private function _setStatus($comment_id, $status) {
		$user = vista_get_user();
		$comment = PV::getModel('user/comment', $comment_id);

		if ( false === $user->isBusiness() ) {
			throw new Vista_Controller_Exception(_('Only business accounts can manage comments.'));
		}

		if ( false === $comment->exists() ) {
			throw new Vista_Controller_Exception(_('That comment does not exist.'));
		}

		if ( false === $comment->belongsTo($user->getId()) ) {
			throw new Vista_Controller_Exception(_('You do not have permission to change the status of this comment.'));
		}

		if ( $status == USER_COMMENT_APPROVED ) {
			PV::recordActivity(USER_ACTIVITY_POST_COMMENT, $comment->getFromUserId(), $comment->getToUserId(), $comment->getComment());
		}

		$comment->setStatus($status)->write();

		return true;
	}

}