<?php

require_once 'application/Account/Account.php';

class Inbox_Controller extends Account_Controller {
	
	public function indexGet() {
		$this->_verifyUserAuth();
		
		try {
			$this->renderLayout('list');
			
		} catch ( Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError();
			
		}
		
		return true;
	}
	
	public function sendGet($profile_id) {
		$this->_verifyUserAuth();
		
		try {
			$profile = PV::getModel('user/profile', $profile_id);
			$user = vista_get_user();
			
			if ( false === $profile->enabled() ) {
				throw new Vista_Controller_Exception(_('The user you are trying to contact is not enabled.'));
			}
			
			if ( $profile->getId() == $user->getId() ) {
				throw new Vista_Controller_Exception(_('You can not send a message to yourself.'));
			}
			
			$this->message = array();
			$this->profile = $profile;
			
			$this->renderLayout('send');
			
		} catch ( Vista_Controller_Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError($e->getMessage(), 'account/index');
			
		} catch ( Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError(_('An error occurred when sending a message.'), 'account/index');
			
		}
		
		return true;
	}

	public function sendPost($profile_id) {
		$this->_verifyUserAuth();
		
		try {
			$profile = PV::getModel('user/profile', $profile_id);
			$user = vista_get_user();

			$msg = (array)$this->getParam('message');
			$validator = $this->buildValidator();
		
			if ( false === $profile->enabled() ) {
				throw new Vista_Controller_Exception(_('The user you are trying to contact is not enabled.'));
			}
			
			if ( $profile->getId() == $user->getId() ) {
				throw new Vista_Controller_Exception(_('You can not send a message to yourself.'));
			}

			$validator->load('message')->setData($msg)->validate();
		
			$message = PV::getModel('user/message')->setDateLastpost(time())
				->setParentId(0)
				->setUserId($user->getId())
				->setSubject($msg['subject'])
				->setBody($msg['body'])
				->setViewCount(0)
				->setStatus(STATUS_ENABLED);
			$message_id = $message->write();
			
			$message->addUser($user->getId());
			$message->addUser($profile->getId());
			
			/* Send an email to the recipient. */
			PV::getEmail()->send('account-new-message', $profile->getEmailAddress(), array(
				'firstname' => $profile->getFirstname(),
				'message_id' => $message_id,
				'subject' => $message->getSubject()
				)
			);
			
			$this->_getMessage()->pushSuccess(_('Your message has successfully been sent.'));
			$this->_redirect($this->url('inbox/view', $message_id));
			
		} catch ( Vista_Controller_Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError($e->getMessage(), 'account/index');
			
		} catch ( Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_getMessage()->pushError(_('An error occurred when attempting to send the message.'));
			
		}
		
		$this->view->setValidator($validator);
		$this->profile = $profile;
		$this->message = $msg;
		$this->renderLayout('send');
		
		return true;
	}

	public function deletePost($message_id, $echo=true) {
		$this->_verifyUserAuth(true);
		$this->setLayout(NULL);
		
		try {
			$message = PV::getModel('user/message', $message_id);
			$user = vista_get_user();
			
			if ( false === $message->enabled() ) {
				throw new Vista_Controller_Exception(_('The message you are attempting to delete does not exist.'));
			}
			
			$is_member = $message->getMemberList()
				->filter('user_id = ?', $user->getId())
				->fetch()
				->length();
			
			if ( 0 === $is_member ) {
				throw new Vista_Controller_Exception(_('You do not have permission to delete this message.'));
			}
			
			$message_member = PV::getModel('user/message/member')
				->find('user_message_id = ?', $message_id)
				->find('user_id = ?', $user->getId())
				->locate()
				->delete();

			$status_text = _('Successfully removed yourself from this message.');
			
		} catch ( Vista_Controller_Exception $e ) {
			
			PV::getLog()->addException($e);
			$status_text = $e->getMessage();
			
		} catch ( Exception $e ) {
			
			PV::getLog()->addException($e);
			$status_text = _('An error occurred when deleting this message.');
			
		}
		
		if ( true === $echo ) {
			echo $status_text;
		}
		
	}

	public function replyPost($message_id) {
		$this->_verifyUserAuth();
		
		try {
			$message = PV::getModel('user/message', $message_id);
			$user = vista_get_user();
			
			$msg = (array)$this->getParam('message');
			
			if ( false === $message->enabled() ) {
				throw new Vista_Controller_Exception(_('The message you are attempting to view does not exist.'));
			}
			
			$is_member = $message->getMemberList()
				->filter('user_id = ?', $user->getId())
				->fetch()
				->length();
			
			if ( 0 === $is_member ) {
				throw new Vista_Controller_Exception(_('You do not have permission to respond to this message.'));
			}
			
			$message_id = PV::getModel('user/message')->setDateLastpost(time())
				->setParentId($message->getId())
				->setUserId($user->getId())
				->setSubject($msg['subject'])
				->setBody($msg['body'])
				->setViewCount(0)
				->setStatus(STATUS_ENABLED)
				->write();
			
			/* Update the last post date of the parent. */
			$message->setDateLastpost(time())->write();
			
			$email_list = $message->getMemberList()
				->filter('user_id <> ?', $user->getId())
				->fetch();
			
			foreach ( $email_list as $email ) {
				$profile = $email->getOwnerProfile();
				
				/* Send an email to the recipients. */
				PV::getEmail()->send('account-new-message', $profile->getEmailAddress(), array(
					'firstname' => $profile->getFirstname(),
					'message_id' => $message->getId(),
					'subject' => $msg['subject']
					)
				);
			}
			
			$this->_getMessage()->pushSuccess(_('Your message has successfully been sent.'));
			$this->_redirect($this->url('inbox/view', $message->getId()));
			
		} catch ( Vista_Controller_Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError($e->getMessage(), 'account/index');
			
		} catch ( Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError(_('An error occurred when responding to this message.'), 'account/index');
			
		}
		
		return true;
	}
	

	public function viewGet($message_id) {
		$this->_verifyUserAuth();
		
		try {
			$message = PV::getModel('user/message', $message_id);

			/* If viewing a child message, get the parent. */
			if ( 0 != $message->getParentId() ) {
				$message = PV::getModel('user/message', $message->getParentId());
			}
			
			$user = vista_get_user();
			
			if ( false === $message->enabled() ) {
				throw new Vista_Controller_Exception(_('The message you are attempting to view is not enabled.'));
			}
			
			if ( false === $message->memberOf($user->getId()) ) {
				throw new Vista_Controller_Exception(_('You do not have permission to view this message.'));
			}
			
			$this->message = $message;
			$this->renderLayout('view');
			
		} catch ( Vista_Controller_Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError($e->getMessage(), 'account/index');
			
		} catch ( Exception $e ) {
			
			PV::getLog()->addException($e);
			$this->_showDisabledError(_('An error occurred when viewing the message.'), 'account/index');
			
		}
		
		return true;
	}

}