<?php

require_once 'application/Root/Root.php';

class Profile_Controller extends Root_Controller {

	public function commentGet($username) {
		$profile_id = vista_get_user_id_by_username($username);
		try {
			$user = vista_get_user();
			$profile = User_Factory::build($profile_id);

			if ( false === $profile->enabled() ) {
				throw new Vista_Controller_Exception(_('The profile you are attempting to view is disabled.'));
			}

			if ( false === $profile->isBusiness() ) {
				throw new Vista_Controller_Exception(_('The profile you are attempting to view is not a business.'));
			}

			$list = $profile->getCommentList()->filter('status = ?', USER_COMMENT_APPROVED);
			$this->profile = $profile;
			$this->list = $list;

			$this->renderLayout('comment-list');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError($e->getMessage());
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		return true;
	}

	public function contactGet($username) {
		$profile_id = vista_get_user_id_by_username($username);
		try {
			$user = vista_get_user();
			$profile = User_Factory::build($profile_id);

			if ( false === $profile->enabled() ) {
				throw new Vista_Controller_Exception(_('The profile you are attempting to view is disabled.'));
			}

			if ( false === $profile->isBusiness() ) {
				throw new Vista_Controller_Exception(_('The profile you are attempting to view is not a business.'));
			}

			$list = $profile->getContactList()
				->filter('status = ?', USER_CONTACT_APPROVED);

			$this->profile = $profile;
			$this->list = $list;

			$this->renderLayout('contact-list');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError($e->getMessage());
		} catch ( Exception $e ) {
			PV::getLog()->addException($e);
			$this->_showDisabledError();
		}

		return true;
	}

	public function statusGet($username) {
		$profile_id = vista_get_user_id_by_username($username);
		try {
			$user = vista_get_user();
			$profile = User_Factory::build($profile_id);

			if ( false === $profile->enabled() ) {
				throw new Vista_Controller_Exception(_('The profile you are attempting to view is disabled.'));
			}

			if ( false === $profile->isBusiness() ) {
				throw new Vista_Controller_Exception(_('The profile you are attempting to view is not a business.'));
			}

			$list = $profile->getStatusList();

			$this->profile = $profile;
			$this->list = $list;

			$this->renderLayout('status-list');
		} catch ( Vista_Controller_Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$this->_showDisabledError($e->getMessage());
		} catch ( Exception $e ) {
			PV::getLog()->add(LOG_EXCEPTION, $e->getMessage());
			$this->_showDisabledError();
		}

		return true;
	}


	public function viewGet($username) {
		if (is_numeric($username)) {
			$profile_id = (int)$username;
		} else {
			$profile_result = PV::getDb()->select()
				->from('user')
				->where('username = ?', $username)
				->query();
			$profile_id = (int)$profile_result->fetch('user_id');
		}

		$user = vista_get_user();
		$profile = User_Factory::build($profile_id);

		if ( false === $profile->enabled() ) {
			$this->renderLayout('profile-disabled');
		} else {
			$is_complete = $profile->isComplete();

			/* Determine if the person viewing the profile actually is the owner of it. */
			$is_owner = false;
			if ( $profile_id == $user->getId() ) {
				$is_owner = true;
			}

			$this->profile = $profile;
			$this->user = $user;
			$this->is_complete = $is_complete;
			$this->is_owner = $is_owner;
			$this->is_logged_in = $this->_getUserSession()->isLoggedIn();

			if ( true === $profile->isConsumer() ) {
				$this->renderLayout('profile-consumer');
			} elseif ( true === $profile->isBusiness() ) {
				/* Register a statistic. */
				PV::getModel('user/statistic')->setFromUserId($user->getId())
					->setToUserId($profile->getId())
					->setType(USER_STATISTIC_PROFILE_VIEW)
					->write();

				/* Get the last X comments to display on the profile. */
				$comment_list = $profile->getCommentList()
					->filter('status = ?', USER_COMMENT_APPROVED)
					->limit(CONFIG_COMMENT_LIST_LENGTH)
					->fetch();

				/* Get the last X contacts to display on the profile. These are the Related To My Company contacts. */
				$friend_list = $profile->getContactList()
					->filter('status = ?', USER_CONTACT_APPROVED)
					->limit(CONFIG_CONTACT_LIST_LENGTH)
					->fetch();

				/* Determine if the person viewing the profile can add them as a contact. */
				$can_friend_one = PV::getDb()->select()
					->from('user_contact')
					->where('from_user_id = ?', $profile_id)
					->where('to_user_id = ?', $user->getId())
					->query()
					->numRows();

				$can_friend_two = PV::getDb()->select()
					->from('user_contact')
					->where('from_user_id = ?', $user->getId())
					->where('to_user_id = ?', $profile_id)
					->query()
					->numRows();

				$can_friend = false;
				if ( 0 == $can_friend_one && 0 == $can_friend_two ) {
					$can_friend = true;
				}
				$this->can_friend = $can_friend;

				/* Determine if they are in the office or out of the office, or don't want to say. */
				$office_status = NULL;
				$this->fullname = $profile->getFullname();

				switch ( $profile->getOfficeStatus() ) {
					case USER_OFFICE_STATUS_IN_OFFICE: {
						$this->status = _('is available');
						$this->status_class = 'in-office';
						$office_status = $this->render('office-status');
						break;
					}

					case USER_OFFICE_STATUS_OUT_OFFICE: {
						$this->status = _('is unavailable');
						$this->status_class = 'out-office';
						$office_status = $this->render('office-status');
						break;
					}
				}

				/* Get their most current commercial. */
				$video = NULL;
				if ( $profile->getUserVideoId() > 0 ) {
					$video = PV::getModel('user/video', $profile->getUserVideoId());
				}

				$this->video = $video;
				$this->office_status = $office_status;
				$this->comment_list = $comment_list;
				$this->friend_list = $friend_list;

				$this->renderLayout('profile-business');
			}
		}

		return true;
	}

	public function viewVideoPost($action, $video_id, $echo=true) {
		$this->setLayout(NULL);

		$video = PV::getModel('user/video', $video_id);

		try {
			if ( false === $video->exists() ) {
				throw new Vista_Controller_Exception(_('The video does not exist.'));
			}

			switch ( $action ) {
				case ACTION_FULL: {
					$full = $video->getViewCountFull();
					$partial = $video->getViewCountPartial();

					$full++;
					if ( $partial > 0 ) {
						$partial--;
					}

					$video->setViewCountFull($full)
						->setViewCountPartial($partial)
						->write();

					if ( true === $echo ) {
						echo $full;
					}

					break;
				}

				case ACTION_PARTIAL: {
					$partial = $video->getViewCountPartial();

					$video->setViewCountPartial(++$partial)->write();
					break;
				}
			}
		} catch ( Vista_Controller_Exception $e ) {

			PV::getLog()->addException($e);

		} catch ( Exception $e ) {

			PV::getLog()->addException($e);

		}

		return true;
	}

	public function renderLayout($view) {
		if ( false === $this->_getUserSession()->isLoggedIn() ) {
			$this->render('profile/register-announcement', 'register-announcement');
		}

		parent::renderLayout($view);
	}
}
