<?php

class Root_Controller extends Artisan_Controller {
	protected $_layout = 'index';

	public function __construct(Artisan_Config $config, $method, $argv=array()) {
		parent::__construct($config, $method, $argv);
	}

	public function renderLayout($view) {
		$user = vista_get_user();

		// Render the basic header information
		$this->css_reset = DIR_CSS . 'reset.css';
		$this->css_grid_960 = DIR_CSS . 'grid-960.css';
		$this->css_prospectvista = DIR_CSS . 'kwolla.css';
		$this->css_jquery_ui = DIR_CSS . 'jquery-ui.css';

		$this->js_jquery = DIR_JAVASCRIPT . 'jquery.js';
		$this->js_jquery_ui = DIR_JAVASCRIPT . 'jquery-ui.js';
		$this->js_jquery_flot = DIR_JAVASCRIPT . 'jquery.flot.js';
		$this->js_flowplayer = DIR_JAVASCRIPT . 'flowplayer.js';
		$this->js_prospectvista = DIR_JAVASCRIPT . 'prospectvista.js';
		$this->js_prospectvista_graph = DIR_JAVASCRIPT . 'prospectvista.graph.js';

		$this->render('root/header', 'header');

		$this->message_list = $this->_getMessage()->display();
		$this->user = $user;
		$this->user_id = $user->getId();
		$this->username = $user->getUsername();
		$this->is_logged_in = $this->_getUserSession()->isLoggedIn();

		$menu_view = $this->_getUserTypeView('menu');

		$this->inbox_count = $user->getMessageList()->length();
		$this->menu = $this->render('root/'.$menu_view);

		$this->locale_list = Artisan_Registry::pop('locale_list');

		$this->render('root/search', 'search');

		// Render the body
		$this->render($view, 'body');

		$this->ga = CONFIG_GOOGLE_ANALYTICS_ACCOUNT;
		$this->render('root/footer', 'footer');
	}

	protected function _getActiveUser() {
		return Artisan_Registry::pop('user');
	}

	protected function _getNewUser($type) {
		switch ( $type ) {
			case USER_TYPE_CONSUMER: {
				$user = PV::getModel('user/consumer');
				break;
			}

			case USER_TYPE_BUSINESS:
			default: {
				$user = PV::getModel('user/business');
				break;
			}
		}

		return $user;
	}

	protected function _getSession() {
		return Artisan_Session::get();
	}

	protected function _getUserSession() {
		return User_Session::get();
	}

	protected function _getMessage() {
		return Message::get();
	}

	protected function _getUserTypeView($root) {
		$type = vista_get_user()->getType();
		switch ( $type ) {
			case USER_TYPE_BUSINESS: {
				$view = '-business';
				break;
			}

			case USER_TYPE_CONSUMER:
			default: {
				$view = '-consumer';
				break;
			}
		}

		$view = $root . $view;
		return $view;
	}

	protected function _verifyUserAuth($ajax=false) {
		if ( false === $this->_getUserSession()->isLoggedIn() ) {
			if ( false === $ajax ) {
				$from_url = trim(er('u', $_REQUEST));
				$this->_getSession()->add('redirect', $from_url);

				$this->_showDisabledError();
			} else {
				exit(_("The action you're attempting to perform is not allowed."));
			}
		}

		if ( false === vista_get_user()->enabled() ) {
			$error = _('Your account is currently disabled. Please click "Enable Account" to re-enable your account');
			$this->_showDisabledError($error, 'account/disabled');
		}

		return true;
	}

	protected function _showDisabledError($error=NULL, $url=NULL) {
		if ( true === empty($error) ) {
			$error = 'Please register and log in before attempting to view that area.';
		}

		if ( true === empty($url) ) {
			$url = 'index/index';
		}

		PV::getLog()->add(LOG_ERROR, 'User is being shown a disabled error: "' . $error . '" and being redirected to "' . $url . '"');

		$this->_getMessage()->pushError(_($error));
		$this->_redirect($this->url($url));
	}

	protected function _redirect($url) {
		header("Location: " . $url);
		exit;
	}

}