function Graph() {

	this.graphId = '',
	this.data = [],
	this.label = '',
	this.lineColor = '#07467e',
	this.fillColor = '#6FC1E4',
	this.legend = true,

	this.setGraphId = function(graphId) {
		this.graphId = graphId;
		return this;
	},

	this.setData = function(data) {
		this.data = data;
		return this;
	},

	this.setFillColor = function(fillColor) {
		if ( fillColor.length > 0 ) {
			this.fillColor = fillColor;
		}
		return this;
	},

	this.setLabel = function(label) {
		this.label = label;
		return this;
	},

	this.setLegend = function(legend) {
		this.legend = legend;
		return this;
	},

	this.setLineColor = function(lineColor) {
		if ( lineColor.length > 0 ) {
			this.lineColor = lineColor;
		}
		return this;
	},


	this.draw = function() {
		var options = {
			data: this.data,
			color: this.lineColor,
			label: this.label,
			lines: {
				show: true,
				fill: true
			}
		};

		// Find the fillColor as rgba
		var r = parseInt(this.fillColor.substring(1,3), 16);
		var g = parseInt(this.fillColor.substring(3,5), 16);
		var b = parseInt(this.fillColor.substring(5,7), 16);

		var plot = $.plot($('#' + this.graphId), [options], {
			legend: {
				position: 'se',
				show: this.legend
			},
			series: {
				lines: {
					show: true,
					lineWidth: 1,
					fillColor: 'rgba(' + r + ',' + g + ',' + g + ', 0.3)'
				},
				points: {
					show: true
				},
				shadowSize: 4
			},
			xaxis: {
				mode: 'time'
			},
			yaxis: {
				tickFormatter: null
			},
			grid: {
				color: '#000',
				hoverable: true,
				autoHighlight: true,
				clickable: true,
				backgroundColor: {
					colors: ['#ffffff', '#e2e2e2']
				},
				mouseActiveRadius: 20,
			},
			points: {
				radius: 3
			}
		});

		var legend = $('#' + this.graphId + ' .legendLabel');
		var currency = this.currency;

		$('#' + this.graphId).bind('plothover', function (event, pos, item) {
			if ( item ) {
				var amount = item.datapoint[1];
				var legendText = amount;

				legend.text(legendText);
			}
		});
	}

}