<?php

require_once 'Object/Email/class.phpmailer.php';

class Email {
	private $_subject = NULL;
	private $_body = NULL;
	private $_alt_body = NULL;
	
	private $_from = NULL;
	private $_from_name = NULL;
	
	private $_template = NULL;
	
	public function __construct() {
		$this->_template = new Artisan_Template_Generic();
	}
	
	public function __destruct() {
		unset($this->_subject, $this->_body, $this->_alt_body);
	}
	
	public function setFrom($from) {
		$this->_from = $from;
		return $this;
	}
	
	public function setFromName($from_name) {
		$this->_from_name = $from_name;
		return $this;
	}
	
	public function setSubject($subject) {
		$this->_subject = $subject;
		return $this;
	}
	
	public function send($email_name, $to_address, $replace_list=array()) {
		$this->_load($email_name);
		
		if ( true === empty($this->_subject) || true === empty($this->_body) ) {
			return false;
		}
		
		$replace_list = array_merge(
			array('site_url' => CONFIG_SITE_URL),
			$replace_list
		);
		
		if ( count($replace_list) > 0 ) {
			$this->_template->setReplaceList($replace_list);
			
			$this->_template->setTemplateCode($this->_body);
			$this->_body = $this->_template->parseTemplate();
			
			$this->_template->setTemplateCode($this->_alt_body);
			$this->_alt_body = $this->_template->parseTemplate();
		}
		
		if ( false === is_array($to_address) ) {
			$to_address = array($to_address);
		}
		
		try {
			$from = ( true === empty($this->_from) ? CONFIG_OWNER_EMAIL : $this->_from );
			$from_name = ( true === empty($this->_from_name) ? CONFIG_OWNER_NAME : $this->_from_name );
			
			$email = new PHPMailer();
			$email->IsHTML(true);
			$email->From     = $from;
			$email->FromName = $from_name;
			$email->Subject  = $this->_subject;
			$email->Body     = $this->_body;
			$email->AltBody  = $this->_alt_body;

			foreach ( $to_address as $address ) {
				$email->AddAddress($address);
			}
			
			$email->Send();
		} catch ( phpmailerException $e ) {
			return false;
		} catch ( Exception $e ) {
			return false;
		}
		
		return true;
	}
	
	protected function _load($email_name) {
		$result_email = PV::getDb()->select()
			->from('email')
			->where('name = ?', $email_name)
			->where('locale = ?', CONFIG_LOCALE)
			->query();
		if ( 1 == $result_email->numRows() ) {
			$email = $result_email->fetch();
			$this->_subject = $email['subject'];
			$this->_body = $email['body'];
			$this->_alt_body = $email['alt_body'];
		}
		return true;
	}
}