<?php

class Image {
	private $_image_location;

	private $_image = NULL;

	public function __construct($image_location) {
		$this->_image_location = $image_location;
	}

	public function __destruct() {
		if ( true === is_resource($this->_image) ) {
			imagedestroy($this->_image);
		}
	}

	public function resize($max_width, $max_height) {
		$this->_load();

		$init_width = imagesx($this->_image);
		$init_height = imagesy($this->_image);

		// If it's wider than taller, we want to use the max width
		if ( $init_width > $max_width && $init_height > $max_height ) {
			if ( $init_width > $init_height ) {
				$ratio = $max_width / $init_width;
				$height = intval($init_height * $ratio);
				$width = intval($max_width);
			} else {
				$ratio = $max_height / $init_height;
				$width = intval($init_width * $ratio);
				$height = intval($max_height);
			}
		} else {
			$width = $init_width;
			$height = $init_height;
		}

		$resized_image = imagecreatetruecolor($width, $height);
		imagecopyresampled($resized_image, $this->_image, 0, 0, 0, 0, $width, $height, $init_width, $init_height);
		$this->_image = $resized_image;

		return $this;
	}

	public function text($text, $size, $x=-1, $y=-1, $red=0, $green=0, $blue=0) {
		$this->_load();

		$font_file = DIR_FONT . CONFIG_FONT;
		if (!is_file($font_file)) {
			return $this;
		}

		$text_color = imagecolorallocate($this->_image, $red, $green, $blue);

		$width_box = imagesx($this->_image);
		$height_box = imagesy($this->_image);

		/* If either of the coordinates are -1, center the text in that direction. */
		$box = imageftbbox($size, 0, $font_file, $text);

		if ( -1 == $x ) {
			$width_text = $box[2] - $box[0];
			$x = floor(($width_box - $width_text) / 2);
		}

		if ( -1 == $y ) {
			$height_text = $box[1] - $box[7];
			$y = floor((($height_box - $height_text) / 2) + $height_text);
		}

		imagettftext($this->_image, $size, 0, $x, $y, $text_color, $font_file, $text);

		return $this;
	}

	public function writeJpg($image_destination = NULL) {
		$this->_write('jpg', $image_destination);
	}

	public function writePng($image_destination = NULL) {
		imagecolortransparent($this->_image, imagecolorallocatealpha($this->_image, 0, 0, 0, 0));
		$this->_write('png', $image_destination);
	}



	private function _write($type, $image_destination = NULL) {
		if ( true === empty($image_destination) ) {
			$image_destination = $this->_image_location;
		}

		$type = strtolower(trim($type));

		switch ( $type ) {
			case 'jpeg':
			case 'jpg': {
				imagejpeg($this->_image, $image_destination, 100);

				break;
			}

			case 'png': {
				imagesavealpha($this->_image, true);
				imagepng($this->_image, $image_destination, 0);
				break;
			}
		}

		return true;
	}

	private function _load() {
		if ( false === is_file($this->_image_location) ) {
			throw new Vista_Exception(_('The image file does not exist.'));
		}

		$file_type = mime_content_type($this->_image_location);
		$file_name = $this->_image_location;

		$this->_image = NULL;
		switch ( $file_type ) {
			case 'image/pjpeg':
			case 'image/jpeg':
			case 'image/jpg': {
				$this->_image = imagecreatefromjpeg($file_name);
				break;
			}

			case 'image/x-png':
			case 'image/png': {
				$this->_image = imagecreatefrompng($file_name);
				break;
			}

			case 'image/gif': {
				$this->_image = imagecreatefromgif($file_name);
				imagealphablending($this->_image, false);
				imagesavealpha($this->_image, true);
				break;
			}
		}

		if ( false === is_resource($this->_image) ) {
			throw new Vista_Exception(_('The file provided is not an allowed image type.'));
		}

		return true;
	}
}