<?php

abstract class Model {
	protected $_id = 0;
	protected $_pkey = NULL;
	protected $_model = array();
	protected $_table = NULL;
	protected $_methodCache = array();
	protected $_forceLoad = false;
	protected $_hasDate = true;

	protected $_findList = array();

	const TABLE_ROOT = '';
	
	public function __construct($id=0) {
		$this->reset();
		$this->load($id);
	}
	
	public function __destruct() {
		$this->_id = 0;
		$this->_model = array();
	}

	public function __call($method, $argv) {
		$argc = count($argv);
		if ( 0 === $argc && true === isset($this->_methodCache[$method]) ) {
			return $this->_methodCache[$method];
		} else {
			$k = substr($method, 3);
			$k = strtolower(substr($k, 0, 1)) . substr($k, 1);
			$k = preg_replace('/[A-Z]/', '_\\0', $k);
			$k = strtolower($k);
			
			if ( 0 === $argc ) {
				/* If the length is 0, assume this is a get() */
				$v = $this->__get($k);
				$this->_methodCache[$method] = $v;
				return $v;
			} else {
				/* Else assume its a set with the first element of $argv. */
				$this->__set($k, current($argv));
				return $this;
			}
		}
	}

	public function __set($k, $v) {
		$this->_model[$k] = $v;
		return true;
	}

	public function __get($k) {
		if ( true === isset($this->_model[$k]) ) {
			return $this->_model[$k];
		}
		return NULL;
	}
	
	/**
	 * ##############################
	 * DETERMINERS
	 * ##############################
	 */
	
	public function exists() {
		return ( $this->_id > 0 );
	}

	public function enabled() {
		if ( false === $this->exists() ) {
			return false;
		}
		
		if ( false === isset($this->_model['status']) ) {
			return true;
		}
	
		if ( 1 === intval($this->_model['status']) ) {
			return true;
		}
		
		return false;
	}
	
	
	
	/**
	 * ##############################
	 * GETTERS
	 * ##############################
	 */
	
	public function get() {
		return $this->_model;
	}

	public function getId() {
		return $this->_id;
	}
	
	public function getPkey() {
		return $this->_pkey;
	}
	
	public function getTable() {
		return $this->_table;
	}
	
	
	/**
	 * ##############################
	 * SETTERS
	 * ##############################
	 */
	
	public function setPkey($pkey) {
		$this->_pkey = $pkey;
		return $this;
	}
	
	public function setTable($table) {
		$this->_table = $table;
		return $this;
	}
	
	
	
	
	
	/**
	 * ##############################
	 * LOCATORS
	 * ##############################
	 */
	
	public function find($field, $value) {
		$this->_findList[] = array($field, $value);
		return $this;
	}
	
	public function locate() {
		$select = PV::getDb()->select();
		$select->from($this->_table);
		
		if ( count($this->_findList) > 0 ) {
			foreach ( $this->_findList as $filter ) {
				$select->where($filter[0], $filter[1]);
			}
		}
		
		$result = $select->query();
		
		if ( 1 === $result->numRows() ) {
			$model = $result->fetch();
			$this->loadModel($model);
		}
	
		return $this;
	}





	
	/**
	 * ##############################
	 * CLASS MODIFIERS
	 * ##############################
	 */
	
	public function reset() {
		$class = strtolower(get_class($this));
		$this->_id = 0;
		$this->_model = array();
		$this->_methodCache = array();
		$this->setTable(self::TABLE_ROOT . $class);
		$this->setPkey($class . '_id');
	}

	

	/**
	 * ##############################
	 * DATA MODIFIERS
	 * ##############################
	 */
	
	public function write() {
		if ( $this->_id > 0 ) {
			$this->_update();
		} else {
			$this->_insert();
		}
		return $this->_id;
	}
	
	public function delete() {
		if ( $this->_id > 0 ) {
			PV::getDb()
				->delete()
				->from($this->_table)
				->where($this->_pkey . ' = ?', $this->_id)
				->limit(1)
				->query();
			if ( 1 == PV::getDb()->affectedRows() ) {
				return true;
			}
		}
		return false;
	}
	
	public function loadModel($array) {
		$this->_model = $array;
		if ( true === isset($array[$this->_pkey]) ) {
			if ( true === $this->_forceLoad ) {
				$this->load($array[$this->_pkey]);
			} else {
				$this->_id = $array[$this->_pkey];
			}
		}
		return $this;
	}
	
	public function load($id) {
		$id = intval($id);
		if ( $id > 0 ) {
			$result = PV::getDb()->select()
				->from($this->_table)
				->where($this->_pkey . ' = ?', $id)
				->query();
			if ( 1 == $result->numRows() ) {
				$model = $result->fetch();
				
				if ( true === isset($model[$this->_pkey]) ) {
					$this->_model = $model;
					$this->_id = $this->_model[$this->_pkey];
					return true;
				}
			}
		}
		return false;
	}
	
	protected function _insert() {
		$date_create = $this->getDateCreate();
		if ( true === $this->_hasDate && true === empty($date_create) ) {
			$this->setDateCreate(time());
		}
		
		PV::getDb()->insert()
			->into($this->_table)
			->values($this->_model)
			->query();

		if ( 1 == PV::getDb()->affectedRows() ) {
			$this->_id = PV::getDb()->insertId();
			return true;
		}
		return false;
	}
	
	protected function _update() {
		$date_modify = $this->getDateModify();
		if ( true === $this->_hasDate && true === empty($date_modify) ) {
			$this->setDateModify(time());
		}
		
		PV::getDb()->update()
			->table($this->_table)
			->set($this->_model)
			->where($this->_pkey . ' = ?', $this->_id)
			->query();
		
		if ( 1 == PV::getDb()->affectedRows() ) {
			return true;
		}
		return false;
	}
}