<?php

class Report_Type_Generator_Gender extends Report_Type_Generator_Abstract {
	public function execute() {
		/**
		 * Because these are complex and not dealing with input data from an untrusted source,
		 * they're just gonna be raw sql.
		 */
		$sql = "SELECT u.user_id, us.user_statistic_id, us.from_user_id,
				FROM_UNIXTIME(us.date_create, '%Y-%m-%d 00:00:00') AS `date_string`
			FROM `user` `u`
			LEFT JOIN `user_statistic` `us`
				ON u.user_id = us.to_user_id
			WHERE (us.processed = '" . STATISTIC_UNPROCESSED . "')
				AND u.type = '" . USER_TYPE_BUSINESS . "'
				AND us.from_user_id <> 0";
		$result_user = PV::getDb()->query($sql);

		$report_data = array();
		while ( $row = $result_user->fetch() ) {
			$user_id = intval($row['user_id']);
			$from_user_id = intval($row['from_user_id']);

			$from_user = PV::getModel('user/profile', $from_user_id);

			if ( true === $from_user->enabled() ) {
				$date_string = $row['date_string'];

				if ( true === empty($date_string) ) {
					$date_string = $this->_startDate;
				}

				$timestamp = strtotime($date_string);
				if ( false === isset($report_data[$user_id]) ) {
					$report_data[$user_id] = array();
				}

				if ( false === isset($report_data[$user_id][$timestamp]) ) {
					$report_data[$user_id][$timestamp] = array('male' => 0, 'female' => 0);
				}

				switch ( $from_user->gender ) {
					case GENDER_FEMALE: {
						$report_data[$user_id][$timestamp]['female']++;
						break;
					}

					case GENDER_MALE: {
						$report_data[$user_id][$timestamp]['male']++;
						break;
					}
				}
			}
		}

		/**
		 * Intentionally done outside of the above loop so if it
		 * throws an exception, the loop doesn't exit without properly
		 * closing the database connection.
		 */
		$report = PV::getModel('report');
		$rdata = PV::getModel('report/data');

		foreach ( $report_data as $user_id => $data ) {
			foreach ( $data as $date_create => $gender_list ) {
				/* Create a new report record. */
				$report_id = $report->setDateCreate($date_create)
					->setUserId($user_id)
					->setTypeId($this->_typeId)
					->setStatus(STATUS_ENABLED)
					->write();

				if ( $report_id > 0 ) {
					/* Create the data. */
					$rdata->setReportId($report_id)
						->setField('female')
						->setValue($gender_list['female'])
						->write();

					$rdata->setReportId($report_id)
						->setField('male')
						->setValue($gender_list['male'])
						->write();
				}

				$report->reset();
				$rdata->reset();
			}
		}
	}
}