<?php

class Tokenizer {
	private $_tokenList = array();
	private $_string = NULL;
	
	const TOKEN_PROXIMITY_LENGTH = 2;
	const TOKEN_CHAR = ' ';
	const TOKEN_MIN_LENGTH = 3;
	
	public function __construct() {
		
	}
	
	public function tokenize($string) {
		$string = strip_tags($string);
		$string = preg_replace('/[^a-z0-9 \-_]/i', NULL, $string);
		$string = preg_replace('/([ ]{2,})/i', ' ', $string);
		$string = strtolower(trim($string));
		$this->_string = $string;
		
		$this->_tokenList = array();
		$token_list = (array)explode(self::TOKEN_CHAR, $this->_string);
		
		$len = count($token_list);
		
		/**
		 * This is for word proximity. What it will do is take N (where N == TOKEN_PROXIMITY_LENGTH)
		 * and find the tokens next to it. Thus, it creates artificial tokens for specific
		 * phrases so that way searching a specific phrase will result in higher hits.
		 * For example, if the full string is:
		 * "mary had a little lamb"
		 * IT would be tokenized as:
		 * - mary
		 * - had
		 * - little
		 * - lamb
		 * - mary had
		 * - had a
		 * - a little
		 * - little lamb
		 * The reason the 'had a' and 'a little' would be included is because the
		 * _addToken() method below is where the token length is taken into consideration,
		 * and because the length of that entire string is greater than TOKEN_MIN_LENGTH,
		 * they'll be added.
		 * You'll obviously have to keep the proximity length pretty low, if you
		 * make it too large, it includes up to that proximity as well, so
		 * a value of 3 would partialy yeild:
		 * - mary had
		 * - mary had little
		 * - had little
		 * - had little lamb
		 */
		for ( $i=0; $i<$len; $i++ ) {
			for ( $j=0; $j<=self::TOKEN_PROXIMITY_LENGTH; $j++ ) {
				$token = array_slice($token_list, $i, $j);
				if ( count($token) == $j ) {
					$this->_addToken(implode(self::TOKEN_CHAR, $token));
				}
			}
		}
		
		return $this->_tokenList;
	}
	
	public function getTokenList() {
		return $this->_tokenList;
	}
	
	private function _addToken($token) {
		$token = trim($token);
		if ( false === empty($token) && strlen($token) >= self::TOKEN_MIN_LENGTH ) {
			if ( true === isset($this->_tokenList[$token]) ) {
				$this->_tokenList[$token]++;
			} else {
				$this->_tokenList[$token] = 1;
			}
		}
		return true;
	}
}