<?php


class Uploader {
	protected $_fileName = NULL;
	protected $_uploadData = array();
	protected $_destinationDirectory = NULL;

	protected $_allowOverwrite = false;

	public function __construct($uploadData = array(), $allow_overwrite=false) {
		$this->setUploadData($uploadData);
		$this->setAllowOverwrite($allow_overwrite);
	}

	public function __destruct() {

	}

	public function getFilename() {
		return $this->_fileName;
	}

	public function getFilenameMed() {
		return ('med_' . $this->_fileName);
	}

	public function getFilenameTn() {
		return ('tn_' . $this->_fileName);
	}

	public function setAllowOverwrite($overwrite) {
		$this->_allowOverwrite = $overwrite;
		return $this;
	}

	public function setUploadData($uploadData) {
		global $lang;

		if ( false === is_array($uploadData) || 0 == count($uploadData) ) {
			throw new Vista_Exception($lang['error_no_video_data']);
		}

		$error = NULL;
		switch ( $uploadData['error'] ) {
			case UPLOAD_ERR_INI_SIZE: {
				$error = $lang['error_upload_ini_size'];
				break;
			}

			case UPLOAD_ERR_FORM_SIZE: {
				$error = $lang['error_upload_form_size'];
				break;
			}

			case UPLOAD_ERR_PARTIAL: {
				$error = $lang['error_upload_partial'];
				break;
			}

			case UPLOAD_ERR_NO_FILE: {
				$error = $lang['error_upload_no_file'];
				break;
			}

			case UPLOAD_ERR_NO_TMP_DIR: {
				$error = $lang['error_upload_no_tmp_dir'];
				break;
			}

			case UPLOAD_ERR_CANT_WRITE: {
				$error = $lang['error_upload_cant_write'];
				break;
			}

			case UPLOAD_ERR_EXTENSION: {
				$error = $lang['error_upload_extension'];
				break;
			}
		}

		if ( false === empty($error) ) {
			throw new Vista_Exception($error);
		}

		$this->_uploadData = $uploadData;
		$this->_fileName = asfw_exists_return('name', $uploadData);
		$this->_fileName = uniqid('vista_', true) . '_' . $this->_fileName;

		return true;
	}

	public function setDestinationDirectory($dest_dir) {
		$dest_dir = DIR_PRIVATE . $dest_dir;
		if ( false === is_dir($dest_dir) ) {
			throw new Vista_Exception(_('The destination directory does not exist.'));
		}

		/* Add the DIRECTORY_SEPARATOR to the last character of the dest_dir if its not one already. */
		$dest_dir = rtrim($dest_dir, DS) . DS;

		$this->_destinationDirectory = $dest_dir;
		return $this;
	}

	public function getDestinationDirectory() {
		return $this->_destinationDirectory;
	}

	public function upload() {
		global $lang;

		if ( 0 == count($this->_uploadData) ) {
			throw new Vista_Exception($lang['error_no_upload_data']);
		}

		$final_file = $this->_destinationDirectory . $this->_fileName;
		if ( true === is_file($final_file) && false === $this->_allowOverwrite ) {
			throw new Vista_Exception($lang['error_file_exists']);
		}

		if ( false === move_uploaded_file($this->_uploadData['tmp_name'], $final_file) ) {
			throw new Vista_Exception($lang['error_failed_upload']);
		}

		return true;
	}
}