<?php

abstract class User extends Model {
	private $_adCreatedList = NULL;
	private $_adSubscriberList = NULL;
	private $_messageList = NULL;
	protected $_requestList = NULL;
	protected $_requestCreatedList = NULL;
	protected $_forumSubscriptionList = NULL;

	public function enabled() {
		return ( true === $this->exists() && USER_STATUS_ENABLED == $this->getStatus() );
	}

	public function isComplete() {
		return ( USER_PROFILE_COMPLETE == $this->getComplete() ? true : false );
	}

	public function isUpgraded() {
		return ( 1 == $this->getUpgrade() ? true : false );
	}

	public function isBusiness() {
		return ( $this->getType() == USER_TYPE_BUSINESS );
	}

	public function isConsumer() {
		return ( $this->getType() == USER_TYPE_CONSUMER );
	}

	public function getFullname() {
		return ($this->getFirstname() . ' ' . $this->getLastname());
	}

	public function getMaxVideoCount() {
		if ( true === $this->isBusiness() && true === $this->isUpgraded() ) {
			return VIDEO_COUNT_PREMIUM;
		} else {
			return VIDEO_COUNT_FREE;
		}
		return 0;
	}

	public function getMaxVideoFilesize() {
		if ( true === $this->isBusiness() && true === $this->isUpgraded() ) {
			return 52428800;
		} else {
			return 20971520;
		}
		return 0;
	}

	public function getOwnerId() {
		return $this->getId();
	}


	public function getMessageList($force=false) {
		if ( NULL === $this->_messageList || true === $force ) {
			$result_message = PV::getDb()->select()
				->from('user_message', 'um', 'um.*')
				->innerJoin('user_message_member', 'um.user_message_id', 'umm.user_message_id')
				->where('umm.user_id = ?', $this->getId())
				->where('um.status = ?', STATUS_ENABLED)
				->where('um.parent_id = 0')
				->orderBy('um.date_lastpost', 'DESC')
				->query();
			$this->_messageList = new Artisan_Db_Iterator($result_message, PV::getModel('user/message'));
		}
		$this->_messageList->rewind();
		return $this->_messageList;
	}

	public function getProspectCard() {
		$card = DIR_PRIVATE . $this->getContentDirectory() . DS . 'card.png';
		return $card;
	}

	public function hasContentDirectory() {
		$content_directory = DIR_PRIVATE . $this->getContentDirectory();
		return (file_exists($content_directory) && is_writable($content_directory));
	}

	public function hasProfileImage() {
		$image_file = DIR_PRIVATE . $this->getContentDirectory() . DS . $this->getProfilePicture();
		return is_file($image_file);
	}

	public function hasProfileMedImage() {
		$image_file = DIR_PRIVATE . $this->getContentDirectory() . DS . $this->getProfilePictureMed();
		return is_file($image_file);
	}

	public function hasProfileTnImage() {
		$image_file = DIR_PRIVATE . $this->getContentDirectory() . DS . $this->getProfilePictureTn();
		return is_file($image_file);
	}

	public function setLastLogin() {
		if ( $this->_id > 0 ) {
			PV::getDb()->update()
				->table('user')
				->set(array('date_lastlogin' => time()))
				->where('user_id = ?', $this->_id)
				->query();
		}
	}

	public function setUsername($username) {
		$username = vista_sanitize_username($username);
		$this->__set('username', $username);
		return $this;
	}

	public function createProspectCard() {
		if ( true === $this->exists() ) {
			$cd = DIR_PRIVATE . $this->getContentDirectory() . DS;
			if ( true === is_dir($cd) ) {
				$name = $this->getFullname();
				$card = new Image(DIR_CONTENT . DIR_IMAGE . 'prospect-card-bg.png');
				$card->text($name, 12, -1, 50, 37, 44, 51)->writePng($cd . 'card.png');
			}
			return true;
		}
		return false;
	}

	public function createContentDirectory() {
		while ( true ) {
			$content_directory = $this->_createContentDirectoryName();
			$content_directory_full = DIR_PRIVATE . $content_directory;

			if ( false === is_dir($content_directory) ) {
				mkdir($content_directory_full, 0755);
				$this->setContentDirectory($content_directory);
				return true;
			}
		}
		return false;
	}

	protected function _insert() {
		if ( true === parent::_insert() ) {
			if ( true === $this->createContentDirectory() ) {
				$this->write();
			}
		}
		return false;
	}

	private function _createContentDirectoryName() {
		$salt1 = substr(asfw_create_salt(), 0, 8);
		$salt2 = substr(asfw_create_salt(), 0, 8);
		$directory = $this->getId() . "_" . $salt1 . "_" . $salt2;
		return $directory;
	}

	abstract public function sendWelcomeEmail();
}