<?php

class User_Business extends User {
	///< Artisan_Db_Iterator for a list of comments.
	private $_commentList = NULL;

	///< Artisan_Db_Iterator for a list of contacts (businesses only).
	private $_contactList = NULL;

	///< Artisan_Db_Iterator for a list of fans (consumers that have favorited them).
	private $_fanList = NULL;

	///< Artisan_Db_Iterator for a list of payments the user has made.
	private $_paymentList = NULL;

	///< Artisan_Db_Iterator for a list of statistics on the user's account.
	private $_statisticList = NULL;

	///< Artisan_Db_Iterator for a list of statuses the user has set.
	private $_statusList = NULL;

	///< Artisan_Db_Iterator for a list of videos the user has.
	private $_videoList = NULL;

	///< Artisan_Db_Iterator for a list of videos in the user's video queue.
	private $_videoQueueList = NULL;

	///< Forum object for
	private $_userForum = NULL;

	public function __construct($id=0) {
		$this->reset();
		$this->setTable('user')->setPkey('user_id');
		$this->load($id);
	}

	/**
	 * Returns the percent complete the profile of a user is.
	 * 20% for the initial account creation.
	 * 30% for updating the profile information.
	 * 10% for upgrading account
	 * 30% for having at least one approved contact.
	 * @author vmc@leftnode.com
	 * @retval integer The percent complete that the profile is
	 */
	public function getPercentComplete() {
		/* Just having an account makes you 20% complete. */
		$percent = 20;

		/* Having updated the account makes it another 20% finished. */
		if ( 1 == $this->_model['complete'] ) {
			$percent += 40;
		}

		/* Being premium services is 10%. */
		if ( true === $this->isUpgraded() ) {
			$percent += 10;
		}

		/* Finally, having one approved contact means they've finished everything up. */
		$contact_length = $this->getContactList()->filter('status = ?', USER_CONTACT_APPROVED)->fetch()->length();
		if ( $contact_length > 0 ) {
			$percent += 30;
		}

		return $percent;
	}


	/**
	 * Returns the comment list iterator.
	 * @author vmc@leftnode.com
	 * @retval Artisan_Db_Iterator The comment list iterator.
	 */
	public function getCommentList($force=false) {
		if ( NULL === $this->_commentList || true === $force ) {
			$result_comment = PV::getDb()->select()
				->from('user_comment')
				->where('to_user_id = ?', $this->getId())
				->orderBy('date_create', 'DESC')
				->query();
			$this->_commentList = new Artisan_Db_Iterator($result_comment, PV::getModel('user/comment'));
		}
		$this->_commentList->rewind();
		return $this->_commentList;
	}

	/**
	 * Returns the contact list iterator.
	 * @author vmc@leftnode.com
	 * @retval Artisan_Db_Iterator The contact list iterator.
	 */
	public function getContactList($force=false) {
		if ( NULL === $this->_contactList || true === $force ) {
			$result_contact = PV::getDb()->select()
				->from('user_contact')
				->where('to_user_id = ?', $this->getId())
				->orderBy('date_create', 'DESC')
				->query();
			$this->_contactList = new Artisan_Db_Iterator($result_contact, PV::getModel('user/contact'));
		}
		$this->_contactList->rewind();
		return $this->_contactList;
	}

	/**
	 * Returns the status list iterator.
	 * @author vmc@leftnode.com
	 * @retval Artisan_Db_Iterator The status list iterator.
	 */
	public function getStatusList($force=false) {
		if ( NULL === $this->_statusList || true === $force ) {
			$result_status = PV::getDb()->select()
				->from('user_status')
				->where('user_id = ?', $this->getId())
				->orderBy('date_create', 'DESC')
				->query();
			$this->_statusList = new Artisan_Db_Iterator($result_status, PV::getModel('user/status'));
		}
		$this->_statusList->rewind();
		return $this->_statusList;
	}

	/**
	 * Returns the statistic list iterator.
	 * @author vmc@leftnode.com
	 * @retval Artisan_Db_Iterator The statistic list iterator.
	 */
	public function getStatisticList($force=false) {
		if ( NULL === $this->_statisticList || true === $force ) {
			$result_statistic = PV::getDb()->select()
				->from('user_statistic', 'us', 'us.*', 'u.*')
				->innerJoin('user', 'us.from_user_id', 'u.user_id')
				->where('us.to_user_id = ?', $this->getId())
				->orderBy('us.date_create', 'DESC')
				->query();
			$this->_statisticList = new Artisan_Db_Iterator($result_statistic, PV::getModel('user/statistic'));
		}
		$this->_statisticList->rewind();
		return $this->_statisticList;
	}

	public function sendWelcomeEmail() {
		PV::getEmail()->send('account-register-business', $this->getEmailAddress(), array('firstname' => $this->getFirstname()));
		return true;
	}

	protected function _insert() {
		if ( true === parent::_insert() ) {
			$this->createProspectCard();

			$forum_name = $this->getFullName();
			$forum_id = PV::getModel('forum')->setUserId($this->getId())
				->setName($forum_name)
				->setDescription($forum_name)
				->setIcon(NULL)
				->setPermission(ACL_PUBLIC)
				->setStatus(FORUM_STATUS_DISABLED)
				->write();

			$this->setForumId($forum_id)->write();

			return true;
		}

		return false;
	}

	protected function _update() {
		if ( true === parent::_update() ) {
			$this->createProspectCard();
			return true;
		}
		return false;
	}

}