<?php 

// Defines
define("LOGGER_ALL"		, "5");
define("LOGGER_ERROR"	, "4");
define("LOGGER_WARNING"	, "3");
define("LOGGER_PARSE"	, "2");
define("LOGGER_NOTICE"	, "1");
define("METHOD_LOG"		, "log");
define("METHOD_MAIL"	, "mail");
define("METHOD_PRINT"	, "print");
define("METHOD_SERVER"	, "server");

// Set reporting to all
error_reporting(E_ALL);

/**
 * @todo log possible hack attempts
 */
class Logger
{
	
	function __construct($mode=LOG_ALL, $method=METHOD_LOG, $logdir=""){
		
		// Set mode
		$this->_mode = $mode;
		
		// Set method
		$this->_method = $method;
		
		// If logdir is empty set default dir
		if(empty($logdir)){
			$this->_logdir = str_replace("\\", "/", dirname(__FILE__)) . "/log/";
		}else{
			$this->_logdir = $logdir;
		}
		
	}
	
	private $_mode;
	private $_method;
	private $_logdir;
	private $_logserver;
	private $_logserver_psk;
	private $_adminemail;
	private $_numbererrors = array(
							    1					=> 'E_ERROR',
							    2					=> 'E_WARNING',
							    4					=> 'E_PARSE',
							    8					=> 'E_NOTICE',
							    16					=> 'E_CORE_ERROR',
							    32					=> 'E_CORE_WARNING',
							    64					=> 'E_COMPILE_ERROR',
							    128					=> 'E_COMPILE_WARNING',
							    256					=> 'E_USER_ERROR',
							    512					=> 'E_USER_WARNING',
							    1024				=> 'E_USER_NOTICE',
							    2048				=> 'E_STRICT');
	private $_stringerrors = array(
							    E_ERROR          	=> 'Error',
							    E_WARNING        	=> 'Warning',
							    E_PARSE          	=> 'Parsing Error',
							    E_NOTICE          	=> 'Notice',
							    E_CORE_ERROR      	=> 'Core Error',
							    E_CORE_WARNING    	=> 'Core Warning',
							    E_COMPILE_ERROR  	=> 'Compile Error',
							    E_COMPILE_WARNING 	=> 'Compile Warning',
							    E_USER_ERROR      	=> 'User Error',
							    E_USER_WARNING    	=> 'User Warning',
							    E_USER_NOTICE    	=> 'User Notice',
							    E_STRICT          	=> 'Runtime Notice');
	
	private function createEntryBody($type, $message, $file, $line, $context){

		$ip 		= $_SERVER['REMOTE_ADDR'];
		$referer 	= isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : "";
		$body		= "";
		
		switch ($this->_method){
			case METHOD_LOG:
				$body = $ip . " - [" . date("d-m-y h:i:s") . "] " . $this->_stringerrors[$type] . ": " . $message . " - " . $file . "(line:" . $line . ")";
				break;
			case METHOD_MAIL:
				$body = "IP: " . $ip . "\nDate: " . date("d-m-y h:i:s") . "\nType: " . $this->_stringerrors[$type] . "\nMessage: " . $message . "\nFile: " . $file . "\nLine: " . $line . "\nHost: " . $_SERVER['HTTP_HOST'];
				$body .= strip_tags($this->extraData());
				break;
			case METHOD_PRINT:
				$body = '<div style="background-color:#FEFFD0;margin-bottom:5px;padding:10px;color:#3379C5;font-family:Arial;font-size:12px">' . $ip . " - [" . date("d-m-y h:i:s") . "] <strong>" . $this->_stringerrors[$type] . "</strong>: " . $message . " - " . $file . "(line:<strong>" . $line . "</strong>)<br />Referer:" . $referer . "</div>";
				$body .= nl2br($this->extraData());
				break;
			case METHOD_SERVER:
				$array['type'] 		= $type;
				$array['message'] 	= $message;
				$array['file'] 		= $file;
				$array['line'] 		= $line;
				$array['ip'] 		= $ip;
				$array['date'] 		= date("d-m-y h:i:s");
				$array['url'] 		= $_SERVER['PHP_SELF'];
				$array['host']		= $_SERVER['HTTP_HOST'];
				$array['crc'] 		= md5($type . $message . $file . $line . $ip . $this->_logserver_psk);
				$body = json_encode($array);
				break;
		}
		
		return $body;
	}
	
	private function extraData(){
		
		// Body var
		$body = "";
		$get_data = array();
		$post_data = array();
		
		// GET result
		$get = "<strong>GET DATA</strong> \n";
		foreach($_GET as $key => $value){
			$get_data[] = $key . "=" . $value;
		}
		if(count($get_data) > 0){
			$body .= $get . implode("\n", $get_data);
		}
		
		// POST result
		$post = "<strong>POST DATA</strong> \n";
		foreach($_POST as $key => $value){
			$post_data[] = $key . "=" . $value;
		}
		if(count($post_data) > 0){
			$body .= "\n\n" . $post . implode("\n", $post_data);
		}
		
		return '<div style="background-color:#FEFFD0;margin:0px 0px 5px 20px;padding:10px;color:#3379C5;font-family:Arial;font-size:11px">' . $body . '</div>';
		
	}
	
	private function createFile($file){
		$file_handle = fopen($file, 'w') or die("can't open file");
		fclose($file_handle);
	}
	
	public function SetServer($server){
		$this->_logserver = $server;
	}
	
	public function SetServerPsk($psk){
		$this->_logserver_psk = $psk;
	}
	
	public function Handle($type, $message, $file, $line, $context){

		// Notice logging
		if($this->_mode < 2 && ($type == E_NOTICE || $type == E_USER_NOTICE)){
			$message = $this->createEntryBody($type, $message, $file, $line, $context);
			$this->log($message);
			return TRUE;
		}
		
		// Parse logging
		if($this->_mode < 3 && $type == E_PARSE){
			$message = $this->createEntryBody($type, $message, $file, $line, $context);
			$this->log($message);
			return TRUE;
		}
		
		// Warning logging
		if($this->_mode < 4 && ($type == E_WARNING || $type == E_CORE_WARNING || $type == E_COMPILE_WARNING || $type == E_USER_WARNING)){
		
			$message = $this->createEntryBody($type, $message, $file, $line, $context);
			$this->log($message);
			return TRUE;
		}
		
		// Error logging
		if($this->_mode < 5 && ($type == E_ERROR || $type == E_CORE_ERROR || $type == E_COMPILE_ERROR || $type == E_USER_ERROR)){
			$message = $this->createEntryBody($type, $message, $file, $line, $context);
			$this->log($message);
			return TRUE;
		}

		if($this->_mode == 5){
			$message = $this->createEntryBody($type, $message, $file, $line, $context);
			$this->log($message);
			return TRUE;
		}
		
	}
	
	public function SetEmail($email){
		$this->_adminemail = $email;
	}
	
	private function log($message){

		switch ($this->_method){
			case METHOD_LOG:
				$logfile = $this->_logdir . date("Ymd") . ".php";
				if(file_exists($logfile)){
					$content = file_get_contents($logfile);
					file_put_contents($logfile, $content . "\n" . $message);
				}else{
					if(!file_exists($this->_logdir)){
						mkdir($this->_logdir, 0755);
					}
					file_put_contents($logfile, "<?php exit() ?>\n" . $message);
				}
				
				break;
			case METHOD_MAIL:
				if(!empty($this->_adminemail)){
					$headers = 'From: noreply@errorsystem' . "\r\n" .
								'X-Mailer: PHP/' . phpversion();
					mail($this->_adminemail, "Logger notify", $message, $headers);
				}else{
					trigger_error("Use the SetEmail to select the destionation address.", E_USER_ERROR);
				}
				break;
			case METHOD_PRINT:
				echo $message;
				break;
			case METHOD_SERVER:
				if(!empty($this->_logserver)){
					$this->post($this->_logserver, array("data" => $message));
				}else{
					trigger_error("Use the SetServer method to select the logserver.", E_USER_ERROR);
				}
				break;
		}
		
	}
	
	private function post($url, $data, $optional_headers=null){
		$fields_string = "";
		foreach($data as $key=>$value) { 
			$fields_string .= $key.'='.$value.'&';
		}
		rtrim($fields_string,'&');
		
	     //open connection
		$ch = curl_init();
		
		//set the url, number of POST vars, POST data
		curl_setopt($ch,CURLOPT_URL,$url);
		curl_setopt($ch,CURLOPT_POST,count($data));
		curl_setopt($ch,CURLOPT_POSTFIELDS,$fields_string);
		
		//execute post
		curl_exec($ch);

		//close connection
		curl_close($ch);

	}
	
	
}


