<?php
/*
	Smooth Feed
	Author: <Denon Studio>
	Published: 200905 :: Denon Studio via ThemeForest.com
*/

$CONFIG_FILE = "config.xml";

class Feed_Config {

    var $dom  = null;
    var $urls = null;
    var $root = null;

    public function __construct() {
        $this->createConfigFile();
        $this->loadConfigurationsFile();
        $this->loadData();
    }

    public function __destruct() {
        $this->saveToFile();
        $this->dom = null;
    }
    
    private function createConfigFile() {
        if (!file_exists($GLOBALS["CONFIG_FILE"])) {
            $this->dom = new DOMDocument();
            $this->dom->loadXML("<configurations />");
            $this->dom->save($GLOBALS["CONFIG_FILE"]);
        } 
    }
    
    private function loadConfigurationsFile() {
        $this->dom = new DOMDocument();
        $this->dom->load($GLOBALS["CONFIG_FILE"]);
    }
    
    private function loadData() {
        $this->root = $this->dom->getElementsByTagName("configurations")->item(0); 
        $this->urls = $this->dom->getElementsByTagName("feed"          );
    }
    
    public function getFeedURLs() {
        $result = array();

        for ($i = 0; $i < $this->urls->length; $i++) {
            $object = array("url" => $this->urls->item($i)->getAttribute("url"),
                            "id"  => $this->urls->item($i)->getAttribute("id" ));
            $result[$i] = $object;
        }

        return $result;
    }
    
    public function clearURLs() {
        while($this->urls->length != 0) {
            $el = $this->urls->item(0);
            $el->parentNode->removeChild($el);
        }

        $this->saveToFile();
        $this->loadData();
    }
    
    public function addURL($url) {
        $id = md5($url);

        for ($i = 0; $i < $this->urls->length; $i++) {
            if (strcmp($this->urls->item($i)->getAttribute("id"), $id) == 0)
                return;        
        }

        $element = $this->dom->createElement("feed");
        $element->setAttribute("url", $url);
        $element->setAttribute("id", md5($url));
        $this->root->appendChild($element);        
        $this->saveToFile();
        $this->loadData();
    } 
    
    public function deleteURL($id) {
        $toRemove = null;
        for ($i = 0; $i < $this->urls->length; $i++) {
            $el = $this->urls->item($i);
            if (strcmp($el->getAttribute("id"),$id) == 0) {
                $toRemove = $el;
                break;            
            }
        }
        
        if ($toRemove) {
            $this->root->removeChild($toRemove);
            $this->saveToFile();
            $this->loadData();
        }
    }
    
    private function saveToFile() {
        $this->dom->save($GLOBALS["CONFIG_FILE"]);
        $this->loadData();
    }
}
?>